SystemOrganization addCategory: #'Glamour-Tests'!

GLMSimpleTransmission subclass: #GLMMockSimpleTransmission
	instanceVariableNames: 'wasTransmited'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GLMMockSimpleTransmission classSide methodsFor: 'as yet unclassified' stamp: 'jorge.ressia 6/2/2009 21:24'!
new

	^super new initialize! !

!GLMMockSimpleTransmission methodsFor: 'testing' stamp: 'jorge.ressia 6/2/2009 21:24'!
initialize

	wasTransmited := false! !

!GLMMockSimpleTransmission methodsFor: 'testing' stamp: 'jorge.ressia 6/2/2009 21:26'!
transmit

	wasTransmited := true.
	super transmit.! !

!GLMMockSimpleTransmission methodsFor: 'testing' stamp: 'jre 9/18/2009 21:45'!
transmitIn: aContext

	wasTransmited := true.
	super transmitIn: aContext! !

!GLMMockSimpleTransmission methodsFor: 'testing' stamp: 'jorge.ressia 6/2/2009 21:23'!
wasTransmited
	^wasTransmited! !

TestCase subclass: #GLMBundleTransmissionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GLMBundleTransmissionTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testPorts 
	"Tests that the origins are set up properly and that their order is retained." 
	 
	| transmission | 
	transmission := GLMBundleTransmission new. 
	transmission 
		addActiveOrigin: 
			((GLMSimplePort new) 
				name: #port1; 
				value: 1). 
	transmission 
		addPassiveOrigin: 
			((GLMSimplePort new) 
				name: #port2; 
				value: 2). 
	transmission 
		addActiveOrigin: 
			((GLMSimplePort new) 
				name: #port3; 
				value: 3). 
	transmission 
		addPassiveOrigin: 
			((GLMSimplePort new) 
				name: #port4; 
				value: 4). 
	transmission destination: (GLMSimplePort new name: #port5). 
	self assert: transmission bundleOrigins size = 4. 
	transmission bundleOrigins 
		do: [:each | self assert: (each isKindOf: GLMBundleOrigin)]. 
	self assert: (transmission bundleOrigins at: 1) port name = #port1. 
	self assert: (transmission bundleOrigins at: 2) port name = #port2. 
	self assert: (transmission bundleOrigins at: 3) port name = #port3. 
	self assert: (transmission bundleOrigins at: 4) port name = #port4. 
	self assert: transmission origins size = 4. 
	transmission origins 
		do: [:each | self assert: (each isKindOf: GLMSimplePort)]. 
	self assert: (transmission origins at: 1) name = #port1. 
	self assert: (transmission origins at: 2) name = #port2. 
	self assert: (transmission origins at: 3) name = #port3. 
	self assert: (transmission origins at: 4) name = #port4. 
	self assert: transmission activeOrigins size = 2. 
	transmission activeOrigins 
		do: [:each | self assert: (each isKindOf: GLMSimplePort)]. 
	self assert: (transmission activeOrigins at: 1) name = #port1. 
	self assert: (transmission activeOrigins at: 2) name = #port3. 
	self assert: transmission passiveOrigins size = 2. 
	transmission passiveOrigins 
		do: [:each | self assert: (each isKindOf: GLMSimplePort)]. 
	self assert: (transmission passiveOrigins at: 1) name = #port2. 
	self assert: (transmission passiveOrigins at: 2) name = #port4. 
	self assert: (transmission destination isKindOf: GLMSimplePort). 
	self assert: transmission destination name = #port5! !

!GLMBundleTransmissionTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testPresentations 
	"Tests that the presentations are set up correctly." 
	 
	| transmission presentation1 presentation2 presentation3 | 
	transmission := GLMBundleTransmission new. 
	transmission 
		addActiveOrigin: 
			((GLMSimplePort new) 
				name: #port1; 
				value: 1). 
	transmission 
		addPassiveOrigin: 
			((GLMSimplePort new) 
				name: #port2; 
				value: 2). 
	transmission destination: (GLMSimplePort new name: #port3). 
	presentation1 := GLMPresentation new title: 'presentation1'. 
	presentation2 := GLMPresentation new title: 'presentation2'. 
	presentation3 := GLMPresentation new title: 'presentation3'. 
	transmission addPresentation: presentation1. 
	transmission addPresentation: presentation2. 
	transmission addPresentation: presentation3.	"Test correct setup" 
	self assert: transmission presentations size = 3. 
	self assert: (transmission presentations at: 1) == presentation1. 
	self assert: (transmission presentations at: 2) == presentation2. 
	self assert: (transmission presentations at: 3) == presentation3! !

!GLMBundleTransmissionTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testTransmitting 
	"Tests that the origins are set up properly and that their order is retained." 
	 
	| transmission | 
	transmission := GLMBundleTransmission new. 
	transmission 
		addActiveOrigin: 
			((GLMSimplePort new) 
				name: #port1; 
				value: 1). 
	transmission destination: (GLMSimplePort new name: #port5). 
	self assert: transmission value = 1. 
	self assert: transmission destination value isNil. 
	transmission transmit. 
	self assert: transmission destination value = 1. 
	transmission 
		addPassiveOrigin: 
			((GLMSimplePort new) 
				name: #port2; 
				value: 2). 
	transmission 
		addActiveOrigin: 
			((GLMSimplePort new) 
				name: #port3; 
				value: 3). 
	transmission 
		addPassiveOrigin: 
			((GLMSimplePort new) 
				name: #port4; 
				value: 4). 
	self assert: transmission value = (GLMMultiValue withAll: #(1 2 3 4)). 
	transmission transmit. 
	self 
		assert: 
			transmission destination value = (GLMMultiValue withAll: #(1 2 3 4))! !

!GLMBundleTransmissionTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testTriggerConditions 
	"Tests that the transmission is triggered only when the active origins change." 
	 
	| transmission port1 port2 | 
	transmission := GLMBundleTransmission new. 
	port1 := GLMPort new name: #port1. 
	port2 := GLMPort new name: #port2. 
	transmission addActiveOrigin: port1. 
	transmission addPassiveOrigin: port2. 
	transmission destination: (GLMPort new name: #port3). 
	self assert: (transmission originatesAt: port1). 
	self assert: (transmission originatesAt: port2) not! !

!GLMBundleTransmissionTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testTriggerConditionsWithParentPort 
	 
	| transmission presentation | 
	transmission := GLMBundleTransmission new. 
	presentation := GLMPresentation new. 
	transmission 
		addActiveOrigin: 
			((GLMParentPort new) 
				presentation: presentation; 
				name: #port1; 
				yourself). 
	self 
		assert: 
			(transmission 
				originatesAt: 
					((GLMParentPort new) 
						presentation: presentation; 
						name: #port1; 
						yourself)). 
	self assert: (transmission originatesAt: (presentation pane port: #port1))! !

TestCase subclass: #GLMCompositePresentationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GLMCompositePresentationTest methodsFor: 'as yet unclassified' stamp: 'tg 1/5/2010 15:18'!
testAdd
	| composite |
	composite := GLMCompositePresentation new.
	composite add: GLMPresentation new.
	self assert: composite isEmpty not.
	self assert: composite presentations size = 1! !

!GLMCompositePresentationTest methodsFor: 'as yet unclassified' stamp: 'tg 1/5/2010 15:17'!
testCreation
	| composite |
	composite := GLMCompositePresentation new.
	self assert: composite isEmpty! !

TestCase subclass: #GLMExplicitBrowserTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GLMExplicitBrowserTest methodsFor: 'tests' stamp: 'tg 12/31/2009 03:25'!
expectedFailures
	^ #(#testCopy)! !

!GLMExplicitBrowserTest methodsFor: 'tests' stamp: 'tg 1/5/2010 03:43'!
testAddTransmissionReturn
	| transmission |
	transmission := GLMSimpleTransmission new.
	self assert: (GLMExplicitBrowser new addTransmission: transmission) == transmission! !

!GLMExplicitBrowserTest methodsFor: 'tests' stamp: 'tg 12/30/2009 02:09'!
testCopy
	 
	| browser pane1 pane2 transmission1 transmission2 copiedBrowser | 
	browser := GLMExplicitBrowser new. 
	
	pane1 := browser addNewPane. 
	pane2 := browser addNewPane. 
	transmission1 := GLMSimpleTransmission new
		origin: (pane2 port: #selection); 
		destination: (browser pane port: #selection); 
		yourself.  
	browser addTransmission: transmission1. 
	transmission2 := GLMBundleTransmission new
		addActiveOrigin: (pane1 port: #selection); 
		destination: (pane2 port: #entity); 
		addPresentation: (GLMPresentation new title: 'presentation1');
		yourself.  
	browser addTransmission: transmission2. 

	copiedBrowser := browser copy.
	self assert: copiedBrowser panes size = 2.
	self assert: copiedBrowser panes first ~~ browser panes first.
	self assert: copiedBrowser panes last ~~ browser panes last.

	self assert: copiedBrowser panes first browser == copiedBrowser.
	self assert: copiedBrowser panes last browser == copiedBrowser.

	self assert: copiedBrowser panes first ports size = 1.
	self assert: copiedBrowser panes first ports first name = #selection.
	self assert: copiedBrowser panes first ports first pane == copiedBrowser panes first.

	self assert: copiedBrowser panes last ports size = 2.
	self assert: copiedBrowser panes last ports first name = #selection.
	self assert: copiedBrowser panes last ports last name = #entity.

	self assert: copiedBrowser transmissions size = 2.
	self assert: copiedBrowser transmissions first ~~ browser transmissions first.
	self assert: copiedBrowser transmissions last ~~ browser transmissions last.

	self assert: (copiedBrowser transmissions first destination pane browser isKindOf: GLMNoBrowser).
	self assert: copiedBrowser transmissions last destination pane browser == copiedBrowser.
	
	self assert: (copiedBrowser transmissions first origin pane browser == copiedBrowser).
	self assert: copiedBrowser transmissions last origins first pane browser == copiedBrowser! !

!GLMExplicitBrowserTest methodsFor: 'tests' stamp: 'TestRunner 11/20/2009 01:07'!
testJumpstartTransmission 
	 
	| browser presentation | 
	browser := GLMExplicitBrowser new. 
	presentation := GLMPresentation new. 
	browser addNewPane. 
	browser 
		addTransmission: 
			((GLMBundleTransmission new)
				addActiveOrigin: (browser pane port: #entity); 
				destination: (browser panes first port: #entity); 
				addPresentation: presentation; 
				yourself). 
	self assert: (browser panes first port: #entity) value isNil. 
	self assert: browser panes first presentations isEmpty. 
	(browser pane port: #entity) value: #foo. 
	self assert: (browser panes first port: #entity) value = #foo. 
	self assert: browser panes first presentations size = 1. 
	self assert: browser panes first presentations first == presentation! !

!GLMExplicitBrowserTest methodsFor: 'tests' stamp: 'jorge.ressia 6/3/2009 09:04'!
testParentPort 
	 
	| browser outerPort1 outerPort2 transmission1 transmission2 | 
	browser := GLMExplicitBrowser new. 
	browser addNewPane. 
	GLMTestPane new addPresentation: browser. 
	outerPort1 := (GLMParentPort new) 
		presentation: browser; 
		name: #outerPort1; 
		yourself. 
	outerPort2 := (GLMParentPort new) 
		presentation: browser; 
		name: #outerPort2; 
		yourself.	"Capturing" 
	browser 
		addTransmission: 
			(transmission1 := (GLMMockSimpleTransmission new) 
				origin: outerPort1; 
				destination: (browser panes first port: #innerPort1); 
				yourself).	"Publishing" 
	browser 
		addTransmission: 
			((transmission2 := GLMMockSimpleTransmission new) 
				origin: (browser panes first port: #innerPort2); 
				destination: outerPort2; 
				yourself). 
	(browser pane port: #outerPort1) value: 42. 
	self assert: (browser panes first port: #innerPort1) value = 42. 
	self assert: transmission1 wasTransmited.
	self deny: transmission2 wasTransmited.
	"self assert: (browser pane port: #outerPort1) seenTransmissions size = 0. "
	"self 
		assert: 
			((browser pane port: #outerPort1) seenTransmissions first isKindOf: 
					GLMSimpleTransmission). 
	self 
		assert: 
			((browser pane port: #outerPort1) seenTransmissions first origin isKindOf: 
					GLMSimplePort). 
	self 
		assert: 
			(browser pane port: #outerPort1) seenTransmissions first destination 
				== (browser pane port: #outerPort1). "
	"self 
		assert: 
			(browser panes first port: #innerPort1) seenTransmissions size = 1. 
	self 
		assert: 
			(browser panes first port: #innerPort1) seenTransmissions first 
				== browser transmissions first. "
	(browser panes first port: #innerPort2) value: 43. 
	self assert: (browser pane port: #outerPort2) value = 43. 
	"self 
		assert: 
			(browser panes first port: #innerPort2) seenTransmissions size = 0. "
	"self 
		assert: 
			((browser panes first port: #innerPort2) seenTransmissions first isKindOf: 
					GLMSimpleTransmission). 
	self 
		assert: 
			((browser panes first port: #innerPort2) seenTransmissions first origin 
				isKindOf: GLMSimplePort). 
	self 
		assert: 
			(browser panes first port: #innerPort2) seenTransmissions first destination 
				== (browser panes first port: #innerPort2). "
	"self assert: (browser pane port: #outerPort2) seenTransmissions size = 1. 
	self 
		assert: 
			(browser pane port: #outerPort2) seenTransmissions first 
				== browser transmissions last"! !

!GLMExplicitBrowserTest methodsFor: 'tests' stamp: 'jorge.ressia 6/2/2009 20:45'!
testSetup 
	 
	| browser pane1 pane2 transmission | 
	browser := GLMExplicitBrowser new. 
	
	pane1 := browser addNewPane. 
	pane2 := browser addNewPane. 
	transmission := (GLMSimpleTransmission new) 
		origin: (pane1 port: #selection); 
		destination: (pane2 port: #entity); 
		yourself.  
	browser addTransmission: transmission. 
	self assert: browser panes size = 2. 
	self assert: browser transmissions size = 1. 
	self assert: browser panes first == pane1. 
	self assert: browser panes last == pane2. 
	self assert: pane1 browser == browser. 
	self assert: pane2 browser == browser. 
	self assert: browser transmissions first == transmission! !

!GLMExplicitBrowserTest methodsFor: 'tests' stamp: 'jorge.ressia 6/2/2009 21:27'!
testSimpleTransmission 
	 
	| browser pane1 pane2 presentation1 presentation2 transmission announcement | 
	browser := GLMExplicitBrowser new. 
	presentation1 := GLMPresentation new. 
	presentation2 := GLMPresentation new. 
	pane1 := browser addNewPane. 
	pane2 := browser addNewPane. 
	pane1 addPresentation: presentation1. 
	pane2 addPresentation: presentation2. 
	transmission := (GLMMockSimpleTransmission new) 
		origin: (pane1 port: #selection); 
		destination: (pane2 port: #entity); 
		yourself. 
	browser addTransmission: transmission. 
	announcement := nil. 
	presentation2 
		when: GLMContextChanged 
		do: [:ann | announcement := ann]. 
	presentation1 selection: 'foo'. 
	self assert: transmission wasTransmited.
	"self assert: (pane1 port: #selection) seenTransmissions size = 0. 
	self assert: (pane2 port: #entity) seenTransmissions size = 1." 
	"self 
		assert: (pane1 port: #selection) seenTransmissions first ~~ transmission. "
	"self assert: (pane2 port: #entity) seenTransmissions first == transmission. "
	self assert: (pane1 port: #selection) value = 'foo'. 
	self assert: (pane2 port: #entity) value = 'foo'. 
	self assert: announcement notNil! !

!GLMExplicitBrowserTest methodsFor: 'tests' stamp: 'jorge.ressia 5/30/2009 12:24'!
testTransmissionBundle 
	 
	| browser pane1 pane2 pane3 presentation1 presentation2 transmission | 
	browser := GLMExplicitBrowser new. 
	presentation1 := GLMPresentation new. 
	presentation2 := GLMPresentation new. 
	pane1 := GLMTestPane new. 
	pane2 := GLMTestPane new. 
	pane3 := GLMTestPane new. 
	pane1 addPresentation: GLMPresentation new. 
	pane2 addPresentation: GLMPresentation new. 
	pane3 addPresentation: presentation1. 
	transmission := (GLMBundleTransmission new) 
		addActiveOrigin: (pane1 port: #selection); 
		addPassiveOrigin: (pane2 port: #selection); 
		destination: (pane3 port: #entity); 
		addPresentation: presentation2; 
		yourself. 
	browser addPane: pane1. 
	browser addPane: pane2. 
	browser addPane: pane3. 
	browser addTransmission: transmission. 
	self assert: pane3 presentations size = 1. 
	self assert: pane3 presentations first == presentation1.	"The first should not trigger any transmission (passive) 
	but the second should." 
	pane2 presentations first selection: #foo. 
	pane1 presentations first selection: #bar. 
	self assert: (pane1 port: #selection) seenTransmissions size = 0. 
	self assert: (pane2 port: #selection) seenTransmissions size = 0. 
	"self 
		assert: (pane1 port: #selection) seenTransmissions first ~~ transmission. 
	self 
		assert: (pane2 port: #selection) seenTransmissions first ~~ transmission." 
	self assert: (pane3 port: #entity) seenTransmissions size = 1. 
	"self assert: (pane3 port: #entity) seenTransmissions first ~~ transmission." 
	"self assert: (pane3 port: #entity) seenTransmissions first value = nil. "
	self assert: (pane3 port: #entity) seenTransmissions last == transmission. 
	self 
		assert: 
			(pane3 port: #entity) value = (GLMMultiValue withAll: #(#bar #foo)). 
	self assert: pane3 presentations size = 1. 
	self assert: pane3 presentations first == presentation2! !

!GLMExplicitBrowserTest methodsFor: 'tests' stamp: 'jorge.ressia 5/30/2009 12:20'!
testTriggeringConditions 
	 
	| browser pane1 pane2 transmission | 
	browser := GLMExplicitBrowser new. 
	browser pane: GLMTestPane new. 
	pane1 := GLMTestPane new. 
	pane2 := GLMTestPane new. 
	transmission := (GLMSimpleTransmission new) 
		origin: (pane1 port: #selection); 
		destination: (pane2 port: #entity); 
		yourself. 
	browser addPane: pane1. 
	browser addPane: pane2. 
	browser addTransmission: transmission. 
	self assert: (pane1 port: #selection) seenTransmissions isEmpty. 
	self assert: (pane2 port: #entity) seenTransmissions isEmpty. 
	(pane1 port: #selection) value: 12. 
	self assert: (pane1 port: #selection) seenTransmissions size = 0. 
	"self 
		assert: 
			((pane1 port: #selection) seenTransmissions first isKindOf: 
					GLMSimpleTransmission). "
	self assert: (pane2 port: #entity) seenTransmissions size = 1. 
	self assert: (pane2 port: #entity) seenTransmissions first == transmission.	"Setting the same value should re-publish but not trigger inner transmissions." 
	(pane1 port: #selection) value: 12. 
	self assert: (pane1 port: #selection) seenTransmissions size = 0. 
	"self 
		assert: 
			((pane1 port: #selection) seenTransmissions first isKindOf: 
					GLMSimpleTransmission). "
	"self 
		assert: 
			((pane1 port: #selection) seenTransmissions last isKindOf: 
					GLMSimpleTransmission). "
	self assert: (pane2 port: #entity) seenTransmissions size = 1. 
	self assert: (pane2 port: #entity) seenTransmissions first == transmission! !

TestCase subclass: #GLMFinderTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GLMFinderTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testPaneCreation 
	 
	| browser | 
	browser := GLMFinder new. 
	browser addPresentation: (GLMPresentation new title: 'presentation1'). 
	self assert: browser panes isEmpty.	"Outer entity changed." 
	(browser pane port: #entity) value: #value1. 
	self assert: browser panes size = 1. 
	self assert: browser panes first browser == browser. 
	self assert: (browser panes first port: #entity) value = #value1. 
	self assert: browser panes first presentations size = 1. 
	self 
		assert: browser panes first presentations first title = 'presentation1'. 
	self 
		assert: 
			browser panes first presentations first ~~ browser presentations first.	"First pane selection changed." 
	(browser panes first port: #selection) value: #value2. 
	self assert: browser panes size = 2. 
	self assert: browser panes last browser == browser. 
	self assert: (browser panes last port: #entity) value = #value2. 
	self 
		assert: browser panes last presentations first title = 'presentation1'. 
	self 
		assert: 
			browser panes last presentations first ~~ browser presentations first. 
	self 
		assert: 
			browser panes last presentations first 
				~~ browser panes first presentations first.	"Second pane selection changed." 
	(browser panes last port: #selection) value: #value3. 
	self assert: browser panes size = 3. 
	self assert: browser panes last browser == browser. 
	self assert: (browser panes last port: #entity) value = #value3.	"First pane selection changed again." 
	(browser panes first port: #selection) value: #value4. 
	self assert: browser panes size = 2. 
	self assert: browser panes last browser == browser. 
	self assert: (browser panes last port: #entity) value = #value4.	"Outer entity changed again." 
	(browser pane port: #entity) value: #value5. 
	self assert: browser panes size = 1. 
	self assert: browser panes last browser == browser. 
	self assert: (browser panes last port: #entity) value = #value5! !

!GLMFinderTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testPortPublishing 
	 
	| browser | 
	browser := GLMFinder new. 
	(browser pane port: #entity) value: #value1. 
	self assert: browser panes size = 1. 
	self assert: browser pane ports size = 1. 
	self assert: (browser pane port: #entity) value = #value1. 
	(browser panes first port: #selection) value: #value2. 
	self assert: browser panes size = 2. 
	self assert: browser pane ports size = 2. 
	self assert: (browser pane port: #entity) value = #value1. 
	self assert: (browser pane port: #selection) value = #value2. 
	(browser panes last port: #selection) value: #value3. 
	self assert: browser panes size = 3. 
	self assert: browser pane ports size = 2. 
	self assert: (browser pane port: #entity) value = #value1. 
	self assert: (browser pane port: #selection) value = #value3. 
	(browser panes first port: #hover) value: #value4. 
	self assert: browser panes size = 3. 
	self assert: browser pane ports size = 3. 
	self assert: (browser pane port: #entity) value = #value1. 
	self assert: (browser pane port: #selection) value = #value3. 
	self assert: (browser pane port: #hover) value = #value4! !

TestCase subclass: #GLMFlexiblePresentationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GLMFlexiblePresentationTest methodsFor: 'as yet unclassified' stamp: 'tg 11/16/2009 15:11'!
testDefault
	| browser |
	browser := GLMTabulator new.
	browser startOn: #(1 2 3).
	self assert: (browser panes first presentations first isKindOf: GLMFlexiblePresentation).
	browser startOn: 1.
	self assert: (browser panes first presentations first isKindOf: GLMFlexiblePresentation).! !

!GLMFlexiblePresentationTest methodsFor: 'as yet unclassified' stamp: 'tg 11/16/2009 15:11'!
testDynamic
	| browser childBrowser |
	childBrowser := GLMFinder new.
	browser := GLMTabulator new.
	browser column: #one.
	browser showOn: #one; using: [
		browser custom: (GLMDynamicPresentation new display: [childBrowser]) ].
	browser startOn: 42.
	self assert: browser panes first presentations first currentPresentation == childBrowser.
	self assert: childBrowser pane == browser panes first ! !

TestCase subclass: #GLMFormattedPresentationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GLMFormattedPresentationTest methodsFor: 'as yet unclassified' stamp: 'tg 9/9/2009 01:10'!
testFormat
	| presentation |
	presentation := GLMFormatedPresentation new.
	presentation format: [:c | c ].
	self assert: (presentation formatedDisplayValueOf: 1) = 1.
	presentation entity: 41.
	presentation format: [:a :c | a + c ].
	self assert: (presentation formatedDisplayValueOf: 1) = 42.
	presentation entity: (GLMMultiValue with: 20 with: 21).
	presentation format: [:a :b :c | a + b + c ].
	self assert: (presentation formatedDisplayValueOf: 1) = 42.
! !

TestCase subclass: #GLMListPresentationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GLMListPresentationTest methodsFor: 'tests' stamp: 'tg 9/20/2009 15:19'!
testChildren
	| tree |
	tree := GLMTreePresentation new.
	tree transformation: [:aNumber | (1 to: aNumber ) collect: #printString ].
	tree children: [:each | self assert: (each isKindOf: String)  ].
	tree entity: 42.! !

!GLMListPresentationTest methodsFor: 'tests' stamp: 'TestRunner 11/15/2009 16:27'!
testCustomValidation
	| pane port presentation |

	pane := GLMPane named: 'test'.
	presentation := GLMListPresentation new.
	pane addPresentation: presentation.
	presentation customValidation: [ :object :aport :entity | 
		aport ~= #selection or: [object = (entity last + 40)] ].
	presentation entity: (OrderedCollection with: 1 with: 2).
	self assert: presentation entity last = 2.
	self assert: (presentation validate: 42 on: (pane port: #selection))! !

!GLMListPresentationTest methodsFor: 'tests' stamp: 'TestRunner 11/15/2009 16:08'!
testToSend
	| list |
	list := GLMListPresentation new.
	list selectionTransformation: [ :x | x + 1 ].
	list entity: ( 1 to: 100 ).
	list selection: 41.
	self assert: list selection = 42! !

!GLMListPresentationTest methodsFor: 'tests' stamp: 'tg 11/15/2009 23:51'!
testValidateOn
	 
	| pane port presentation| 
	pane := GLMPane named: 'test'. 
	presentation := GLMListPresentation new.
	pane addPresentation: presentation.
	presentation shouldValidate: true.
	presentation entity: ($a to: $d).
	self deny: (presentation validate: (Array with: $a) on: (pane port: #selection)).
	self deny: (presentation validate: (Array with: $a with: $b) on: (pane port: #selection)).
	self assert: (presentation validate: $a on: (pane port: #selection)).
	self assert: (presentation validate: $b on: (pane port: #selection)).
	self deny: (presentation validate: $z on: (pane port: #selection)).! !

!GLMListPresentationTest methodsFor: 'tests' stamp: 'tg 11/15/2009 23:50'!
testValidatePorts
	 
	| pane port presentation| 
	pane := GLMPane named: 'test'.
	presentation := GLMListPresentation new.
	pane addPresentation: presentation.
	presentation shouldValidate: true.
	presentation entity: #(1 2).
	presentation selection: 2.
	self assert: presentation selection = 2.
	presentation selection: 3."this should be invalid"
	self assert: presentation selection = 2! !

!GLMListPresentationTest methodsFor: 'tests' stamp: 'tg 11/15/2009 23:49'!
testValidateWithMultipleSelection
	 
	| pane port presentation| 
	pane := GLMPane named: 'test'. 
	presentation := GLMListPresentation new.
	presentation beMultiple.
	presentation shouldValidate: true.
	pane addPresentation: presentation.
	presentation entity: ($a to: $d).
	self assert: (presentation validate: (Array with: $a) on: (pane port: #selection)).
	self assert: (presentation validate: (Array with: $a with: $b) on: (pane port: #selection)).
	self deny: (presentation validate: ($a) on: (pane port: #selection)).
	self deny: (presentation validate: (Array with: $z) on: (pane port: #selection)).! !

TestCase subclass: #GLMNestedBrowserTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GLMNestedBrowserTest methodsFor: 'tests' stamp: 'jorge.ressia 6/2/2009 21:43'!
testChangeInnerSelection 
	"Tests setting the selection of an inner pane from the oustide. 
 
	The test sets up a browser with two panes. The first contains a 
	list of numbers, the second a browser which again contains one 
	pane with a list of the same numbers. When the selection in the 
	first pane changes, we want the same number to be selected in 
	the second pane. 
 
	To achieve this, we pull in a port on the second pane and copy 
	it to the inner pane using a simple transmission." 
	 
	| browser1 browser2 list1 list2 | 
	browser1 := GLMExplicitBrowser new. 
	browser2 := GLMExplicitBrowser new. 
	list1 := GLMListPresentation new. 
	list2 := GLMListPresentation new. 
	browser1 addNewPane. 
	browser1 addNewPane. 
	browser2 addNewPane. 
	browser1 panes first addPresentation: list1. 
	browser1 panes last addPresentation: browser2. 
	browser2 panes first addPresentation: list2. 
	browser1 
		addTransmission: 
			((GLMSimpleTransmission new) 
				origin: (browser1 panes first port: #selection); 
				destination: (browser1 panes last port: #innerSelection); 
				yourself). 
	browser2 
		addTransmission: 
			((GLMSimpleTransmission new) 
				origin: 
						((GLMParentPort new) 
								presentation: browser2; 
								name: #innerSelection; 
								yourself); 
				destination: (browser2 panes first port: #selection); 
				yourself). 
	list1 entity: #(1 2 3). 
	list2 entity: #(1 2 3). 
	list1 selection: 1. 
	self assert: list2 selection = 1. 
	list1 selection: 2. 
	self assert: list2 selection = 2! !

!GLMNestedBrowserTest methodsFor: 'tests' stamp: 'jorge.ressia 6/2/2009 21:44'!
testEntityPropogation 
	"This tests the order in which presentations and values are updated. 
 
	This is of importance as, in this test, we add a browser to a pane when a 
	certain port of that pane gets updated using a BundleTransmission but this 
	browser has a transmission from its #outer pane that refers to the same 
	port.  In such a case we want the presentation to be set first so that it can 
	be notified when the outer port changes." 
	 
	| browser1 browser2 presentation | 
	browser1 := GLMExplicitBrowser new. 
	browser2 := GLMExplicitBrowser new. 
	presentation := GLMPresentation new. 
	browser1 addNewPane. 
	browser2 addNewPane.	"Jumpstart presentation for outer browser." 
	browser1 
		addTransmission: 
			((GLMBundleTransmission new) 
				addActiveOrigin: 
						((GLMParentPort new) 
								presentation: browser1; 
								name: #entity; 
								yourself); 
				destination: (browser1 panes first port: #entity); 
				addPresentation: browser2; 
				yourself).	"Jumpstart presentation for inner browser." 
	browser2 
		addTransmission: 
			((GLMBundleTransmission new) 
				addActiveOrigin: 
						((GLMParentPort new) 
								presentation: browser2; 
								name: #entity; 
								yourself); 
				destination: (browser2 panes first port: #entity); 
				addPresentation: presentation; 
				yourself). 
	self assert: (browser1 pane port: #entity) value isNil. 
	self assert: browser1 panes size = 1. 
	self assert: (browser1 panes first port: #entity) value isNil. 
	self assert: browser1 panes first presentations isEmpty. 
	self assert: browser2 panes size = 1. 
	self assert: (browser2 panes first port: #entity) value isNil. 
	self assert: browser2 panes first presentations isEmpty. 
	(browser1 pane port: #entity) value: 42. 
	self assert: (browser1 pane port: #entity) value = 42. 
	self assert: browser1 panes size = 1. 
	self assert: (browser1 panes first port: #entity) value = 42. 
	self assert: browser1 panes first presentations size = 1. 
	self assert: browser1 panes first presentations first == browser2. 
	self assert: browser2 panes size = 1. 
	self assert: (browser2 panes first port: #entity) value = 42. 
	self assert: browser2 panes first presentations size = 1. 
	self assert: browser2 panes first presentations first == presentation! !

!GLMNestedBrowserTest methodsFor: 'tests' stamp: 'jorge.ressia 6/2/2009 21:44'!
testEntityPropogationAnnouncements 
	"This tests the order in which announcements are raised in nested browsers. 
 
	This is of importance as, in this test, we add a browser to a pane when a 
	certain port of that pane gets updated using a BundleTransmission but this 
	browser has a transmission from its #outer pane that refers to the same 
	port.  In such a case we want the presentation to be set first so that it can 
	be notified when the outer port changes. 
 
	This is a sister test to testEntityPropogation that ensures that the 
	announcements are raised in the right order and not redundantly." 
	 
	| browser1 browser2 presentation announcements | 
	browser1 := GLMExplicitBrowser new. 
	browser2 := GLMExplicitBrowser new. 
	presentation := GLMPresentation new. 
	browser1 pane. 
	browser1 addNewPane. 
	browser2 addNewPane. 
	announcements := OrderedCollection new. 
	self assert: browser1 pane presentations size = 1. 
	self assert: browser1 pane presentations first == browser1. 
	browser1 whenContextChanged: [:ann | announcements addLast: ann]. 
	browser2 whenContextChanged: [:ann | announcements addLast: ann]. 
	presentation whenContextChanged: [:ann | announcements addLast: ann]. 
	browser1 pane 
		whenPresentationsChanged: [:ann | announcements addLast: ann]. 
	browser1 panes first 
		whenPresentationsChanged: [:ann | announcements addLast: ann]. 
	browser2 panes first 
		whenPresentationsChanged: [:ann | announcements addLast: ann]. 
	browser1 pane 
		whenMatchingPresentationsChanged: [:ann | announcements addLast: ann]. 
	browser1 panes first 
		whenMatchingPresentationsChanged: [:ann | announcements addLast: ann]. 
	browser2 panes first 
		whenMatchingPresentationsChanged: [:ann | announcements addLast: ann].	"Jumpstart presentation for outer browser." 
	browser1 
		addTransmission: 
			((GLMBundleTransmission new) 
				addActiveOrigin: 
						((GLMParentPort new) 
								presentation: browser1; 
								name: #entity; 
								yourself); 
				destination: (browser1 panes first port: #entity); 
				addPresentation: browser2; 
				yourself).	"Jumpstart presentation for inner browser." 
	browser2 
		addTransmission: 
			((GLMBundleTransmission new) 
				addActiveOrigin: 
						((GLMParentPort new) 
								presentation: browser2; 
								name: #entity; 
								yourself); 
				destination: (browser2 panes first port: #entity); 
				addPresentation: presentation; 
				yourself). 
	self assert: announcements isEmpty. 
	(browser1 pane port: #entity) value: 42. 
	self assert: announcements size = 8.	"1. The outer browser's outer pane changes its value." 
	self assert: ((announcements at: 1) isKindOf: GLMContextChanged). 
	self assert: (announcements at: 1) presentation == browser1. 
	self assert: (announcements at: 1) property = #entity. 
	self assert: (announcements at: 1) value = 42.	"2. The jumpstart transmission of the outer browser is triggered, updating the presentations..." 
	self assert: ((announcements at: 2) isKindOf: GLMPresentationsChanged). 
	self assert: (announcements at: 2) pane == browser1 panes first. 
	self assert: (announcements at: 2) oldPresentations isEmpty. 
	self assert: (announcements at: 2) presentations size = 1. 
	self assert: (announcements at: 2) presentations first == browser2.	"3. ...and then the context." 
	self assert: ((announcements at: 3) isKindOf: GLMContextChanged). 
	self assert: (announcements at: 3) presentation == browser2. 
	self assert: (announcements at: 3) property = #entity. 
	self assert: (announcements at: 3) value = 42.	"4. The jumpstart transmission of the inner browser is triggered, updating the presentations..." 
	self assert: ((announcements at: 4) isKindOf: GLMPresentationsChanged). 
	self assert: (announcements at: 4) pane == browser2 panes first. 
	self assert: (announcements at: 4) oldPresentations isEmpty. 
	self assert: (announcements at: 4) presentations size = 1. 
	self assert: (announcements at: 4) presentations first == presentation.	"5. ...and then the context." 
	self assert: ((announcements at: 5) isKindOf: GLMContextChanged). 
	self assert: (announcements at: 5) presentation == presentation. 
	self assert: (announcements at: 5) property = #entity. 
	self assert: (announcements at: 5) value = 42.	"6. Due to the context change of 5, the innermost presentation now matches." 
	self 
		assert: ((announcements at: 6) isKindOf: GLMMatchingPresentationsChanged). 
	self assert: (announcements at: 6) pane == browser2 panes first. 
	self assert: (announcements at: 6) oldMatchingPresentations isEmpty. 
	self assert: (announcements at: 6) matchingPresentations size = 1. 
	self 
		assert: (announcements at: 6) matchingPresentations first == presentation.	"7. Due to the context change of 3, the inner browser now matches." 
	self 
		assert: ((announcements at: 7) isKindOf: GLMMatchingPresentationsChanged). 
	self assert: (announcements at: 7) pane == browser1 panes first. 
	self assert: (announcements at: 7) oldMatchingPresentations isEmpty. 
	self assert: (announcements at: 7) matchingPresentations size = 1. 
	self assert: (announcements at: 7) matchingPresentations first == browser2.	"8. Due to the context change of 1, the outer browser now matches." 
	self 
		assert: ((announcements at: 8) isKindOf: GLMMatchingPresentationsChanged). 
	self assert: (announcements at: 8) pane == browser1 pane. 
	self assert: (announcements at: 8) oldMatchingPresentations isEmpty. 
	self assert: (announcements at: 8) matchingPresentations size = 1. 
	self assert: (announcements at: 8) matchingPresentations first == browser1! !

TestCase subclass: #GLMNewScriptingTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GLMNewScriptingTest methodsFor: 'as yet unclassified' stamp: 'tg 1/5/2010 17:26'!
testBundleTransmission
	| browser transmission | 
	browser := GLMTabulator new. 
	browser column: #one; column: #two; column: #three. 
	browser transmit from: #one -> #port1; from: #two -> #port2; to: #three -> #port3; showing: [ :a |
		a list.
		a table ].
	transmission := browser transmissions first.
	self assert: browser transmissions size = 1.
	self assert: transmission browser == browser.
	self assert: (transmission isKindOf: GLMBundleTransmission). 
	self assert: transmission origins size = 2.
	self assert: transmission origins first = ((browser paneNamed: #one) port: #port1). 
	self assert: transmission origins last = ((browser paneNamed: #two) port: #port2). 
	self assert: transmission destination = ((browser paneNamed: #three) port: #port3).
	self assert: (transmission presentations isKindOf: GLMCompositePresentation).
	self assert: transmission presentations size = 2! !

!GLMNewScriptingTest methodsFor: 'as yet unclassified' stamp: 'tg 1/5/2010 15:09'!
testSimpleTransmission
	| browser | 
	browser := GLMTabulator new. 
	browser column: #one; column: #two. 
	browser send from: #one -> #port1; to: #two -> #port2.
	self assert: browser transmissions size = 1.
	self assert: browser transmissions first browser == browser.
	self assert: (browser transmissions first isKindOf: GLMSimpleTransmission). 
	self assert: browser transmissions first origin = ((browser paneNamed: #one) port: #port1). 
	self assert: browser transmissions first destination = ((browser paneNamed: #two) port: #port2).
! !

!GLMNewScriptingTest methodsFor: 'as yet unclassified' stamp: 'tg 1/5/2010 19:38'!
testStartTabulator
	| browser | 
	browser := GLMTabulator new. 
	browser column: #one. 
	browser transmit to: #one; showing: [ :a |
		a list.
		a text ].
	browser startOn: 42. 
	self assert: ((browser paneNamed: #one) presentations isKindOf: GLMCompositePresentation).
	self assert: (browser paneNamed: #one) presentations size = 2! !

TestCase subclass: #GLMNoBrowserTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GLMNoBrowserTest methodsFor: 'as yet unclassified' stamp: 'jorge.ressia 6/3/2009 08:35'!
testCreation

	self deny: GLMNoBrowser new isNil.
	self assert: (GLMNoBrowser new) == GLMNoBrowser new! !

TestCase subclass: #GLMPaneTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GLMPaneTest methodsFor: 'tests' stamp: 'jorge.ressia 6/2/2009 20:26'!
testCreation
	 
	| aPane | 
	aPane := GLMPane named: 1 in: 2. 
	self assert: aPane name = 1.
	self assert: aPane browser = 2.! !

!GLMPaneTest methodsFor: 'tests' stamp: 'tg 11/12/2009 22:01'!
testDefaultPortValue
	| pane |
	pane := GLMPane named: 'test'.
	self assert: (pane port: #somePort) value isNil! !

!GLMPaneTest methodsFor: 'tests' stamp: 'tg 1/5/2010 21:07'!
testDefaultPresentations
	| pane |
	pane := GLMPane named: 'test'.
	self assert: (pane presentations isKindOf: GLMCompositePresentation)! !

!GLMPaneTest methodsFor: 'tests' stamp: 'JorgeRessia 11/6/2009 12:36'!
testDefaultValidate
	 
	| pane port | 
	pane := GLMPane named: 'test'. 
	self assert: ((pane port: #selection) validate: 5)
! !

!GLMPaneTest methodsFor: 'tests' stamp: 'jorge.ressia 6/3/2009 09:13'!
testIn
	 
	| aPane | 
	aPane := GLMPane in: 1.
	self assert: aPane name = aPane defaultName.
	self assert: aPane browser = 1.
	self assert: aPane ports isEmpty.
	self assert: aPane presentations isEmpty.! !

!GLMPaneTest methodsFor: 'tests' stamp: 'jorge.ressia 6/3/2009 08:26'!
testNamed
	 
	| aPane | 
	aPane := GLMPane named: 1.
	self assert: aPane name = 1.
	self assert: aPane browser = GLMNoBrowser new.
	self assert: aPane ports isEmpty.
	self assert: aPane presentations isEmpty.! !

!GLMPaneTest methodsFor: 'tests' stamp: 'jorge.ressia 6/3/2009 08:05'!
testNamedIn
	 
	| aPane | 
	aPane := GLMPane named: 1 in: 2. 
	self assert: aPane name = 1.
	self assert: aPane browser = 2.
	self assert: aPane ports isEmpty.
	self assert: aPane presentations isEmpty.! !

!GLMPaneTest methodsFor: 'tests' stamp: 'jorge.ressia 6/3/2009 08:06'!
testPorts 
	 
	| pane port | 
	pane := GLMPane named: 'test'. 
	self assert: pane ports isEmpty. 
	port := pane port: #foo. 
	self assert: pane ports size = 1. 
	self assert: pane ports first == port. 
	self assert: (pane port: #foo) == port! !

!GLMPaneTest methodsFor: 'tests' stamp: 'jorge.ressia 6/3/2009 09:15'!
testPortsInmmutability
	 
	| aPane ports | 
	aPane := GLMPane in: 1.
	self assert: aPane ports isEmpty.
	ports := aPane ports.
	ports add: 1.
	self assert: ports size = 1.
	self assert: aPane ports isEmpty.! !

!GLMPaneTest methodsFor: 'tests' stamp: 'tg 9/11/2009 16:04'!
testPresentationConditions 
	 
	| pane presentation1 presentation2 presentation3 | 
	pane := GLMPane named: 'test'. 
	presentation1 := GLMPresentation new condition: [:first :second | first = 1 and: [second = 2]]. 
	presentation2 := GLMPresentation new condition: [:first | first = #foo]. 
	presentation3 := GLMPresentation new useExplicitNotNil. 
	pane addPresentation: presentation1. 
	pane addPresentation: presentation2. 
	pane addPresentation: presentation3. 
	(pane port: #entity) value: (GLMMultiValue withAll: #(1 2)). 
	self assert: pane matchingPresentations size = 2. 
	self assert: pane matchingPresentations first == presentation1. 
	self assert: pane matchingPresentations last == presentation3. 
	(pane port: #entity) value: (GLMMultiValue withAll: #(#foo 2)). 
	self assert: pane matchingPresentations size = 2. 
	self assert: pane matchingPresentations first == presentation2. 
	self assert: pane matchingPresentations last == presentation3. 
	(pane port: #entity) value: (GLMMultiValue withAll: #(nil 2)). 
	self assert: pane matchingPresentations size = 1! !

!GLMPaneTest methodsFor: 'tests' stamp: 'jorge.ressia 6/3/2009 08:07'!
testPresentations 
	 
	| pane presentation announcement | 
	pane := GLMPane named: 'test'. 
	presentation := GLMPresentation new. 
	self assert: pane presentations isEmpty. 
	announcement := nil. 
	pane whenPresentationsChanged: [:ann | announcement := ann]. 
	pane addPresentation: presentation. 
	self assert: pane presentations size = 1. 
	self assert: pane presentations first == presentation. 
	self assert: presentation pane == pane. 
	self assert: announcement notNil! !

!GLMPaneTest methodsFor: 'tests' stamp: 'jorge.ressia 6/3/2009 09:16'!
testPresentationsInmmutability
	 
	| aPane presentations | 
	aPane := GLMPane in: 1.
	self assert: aPane presentations isEmpty.
	presentations := aPane presentations.
	presentations add: 1.
	self assert: presentations size = 1.
	self assert: aPane presentations isEmpty.! !

!GLMPaneTest methodsFor: 'tests' stamp: 'jorge.ressia 6/3/2009 08:07'!
testSimplePresentations 
	 
	| pane presentation announcement | 
	pane := GLMPane named: 'test'. 
	presentation := GLMPresentation new. 
	self assert: pane presentations isEmpty. 
	announcement := nil. 
	pane whenPresentationsChanged: [:ann | announcement := ann]. 
	pane addPresentation: presentation. 
	self assert: pane presentations size = 1. 
	self assert: pane presentations first == presentation. 
	self assert: presentation pane == pane. 
	self assert: announcement notNil! !

!GLMPaneTest methodsFor: 'tests' stamp: 'tg 11/15/2009 23:54'!
testValidate
	 
	| pane port presentation| 
	pane := GLMPane named: 'test'. 
	presentation := GLMListPresentation new.
	pane addPresentation: presentation.
	presentation entity: (OrderedCollection with: 1 with: 2).
	presentation shouldValidate: true.
	self assert: ((pane port: #selection) validate: 1).
	self assert: ((pane port: #selection) validate: 2).
	self deny: ((pane port: #selection) validate: 5)
! !

TestCase subclass: #GLMPortEventTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GLMPortEventTest methodsFor: 'testing' stamp: 'jorge.ressia 5/30/2009 12:59'!
testCreation
	| anEvent |
	anEvent := GLMPortEvent 
		on: 1
		previouslyValued: 2.
	self assert: anEvent port = 1.
	self assert: anEvent oldValue = 2.
	self assert: anEvent transmissionContext isEmpty.! !

!GLMPortEventTest methodsFor: 'testing' stamp: 'jre 9/19/2009 11:36'!
testCreationWithTransmissionContext
	| anEvent aContext|
	aContext := OrderedCollection new.
	anEvent := GLMPortEvent 
		on: 1
		previouslyValued: 2
		in: aContext.
	self assert: anEvent port = 1.
	self assert: anEvent oldValue = 2.
	self assert: anEvent transmissionContext = aContext.! !

!GLMPortEventTest methodsFor: 'testing' stamp: 'tg 11/16/2009 15:11'!
testInterdependentPanes
	|browser outerCount oneCount |
	outerCount := 0.
	oneCount := 0.
	browser := GLMTabulator new.
	browser column: #one; column: #two; column: #three.
	browser showOn: #one; using: [
		browser list
			display: [:x | 1 to: x]].
	browser showOn: #two; from: #one; using: [
		browser list
			display: [:x | 1 to: x*2]].
	browser showOn: #three; from: #two; using: [
		browser list
			display: [:x | 1 to: x*3];
			update: #focus on: $f entitled: 'Focus' with: [:list | list selection] ].
	browser sendTo: #outer->#focus from: #three->#focus with: [:x | outerCount := outerCount + 1].
	browser sendTo: #one->#selection from: #outer->#focus with: [:x | oneCount := oneCount + 1].
	browser startOn: 5.
	((browser paneNamed: #one) port: #selection) value: 3.
	((browser paneNamed: #two) port: #selection) value: 6.
	((browser paneNamed: #three) port: #selection) value: 12.
	((browser paneNamed: #three) port: #focus) value: 12.
	self assert: oneCount = 1.
	self assert: outerCount = 1.! !

!GLMPortEventTest methodsFor: 'testing' stamp: 'tg 11/16/2009 15:11'!
testInterdependentPanes2
	|browser |
	browser := GLMTabulator new.
	browser column: #one; column: #two; column: #three.
	browser showOn: #one; using: [
		browser list
			display: [:x | 1 to: x]].
	browser showOn: #two; from: #one; using: [
		browser list
			display: [:x | 1 to: x*2]].
	browser showOn: #three; from: #two; using: [
		browser list
			display: [:x | 1 to: x*3];
			update: #focus on: $f entitled: 'Focus' with: [:list | list selection] ].
	browser sendTo: #outer->#focus from: #three->#focus.
	browser sendTo: #one->#selection from: #outer->#focus with: [:x | x + 1].
	browser sendTo: #two->#selection from: #outer->#focus with: [:x | x + 2].
	browser startOn: 5.
	((browser paneNamed: #one) port: #selection) value: 3.
	((browser paneNamed: #two) port: #selection) value: 6.
	((browser paneNamed: #three) port: #selection) value: 12.
	((browser paneNamed: #three) port: #focus) value: 12.
	self assert: (browser pane port: #focus) value = 12.
	self assert: ((browser paneNamed: #one) port: #entity) value = 5.
	self assert: ((browser paneNamed: #one) port: #selection) value = 13.
	self assert: ((browser paneNamed: #two) port: #entity) value = 13.
	self assert: ((browser paneNamed: #two) port: #selection) value = 14.
	self assert: ((browser paneNamed: #three) port: #entity) value = 14.
	self assert: ((browser paneNamed: #three) port: #selection) value = nil.! !

!GLMPortEventTest methodsFor: 'testing' stamp: 'jorge.ressia 5/30/2009 12:02'!
testPortName
	| anEvent |
	anEvent := GLMPortEvent 
		on: ((GLMPort new) name: '1'; yourself)
		previouslyValued: 2.
	self assert: anEvent portName = '1'.
! !

TestCase subclass: #GLMPortTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GLMPortTest methodsFor: 'tests' stamp: 'tg 11/19/2009 22:49'!
testPanePort 
	 
	| port | 
	port := GLMTestPane new port: #port1. 
	self assert: port seenTransmissions isEmpty. 
	port value: 42. 
"	self assert: port seenTransmissions size = 0. 
	self assert: port seenTransmissions first origin value = 42. 
	self assert: port seenTransmissions first origin ~= port. 
	self assert: port seenTransmissions first destination == port. 
	self assert: port value = 42"! !

!GLMPortTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testParentPort 
	 
	| presentation port | 
	presentation := GLMPresentation new. 
	port := (GLMParentPort new) 
		name: #port; 
		presentation: presentation. 
	port value: 42. 
	self assert: (presentation pane port: #port) value = 42. 
	(presentation pane port: #port) value: 43. 
	self assert: port value = 43! !

!GLMPortTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testPortEquality 
	 
	| presentation port | 
	presentation := GLMPresentation new. 
	port := (GLMParentPort new) 
		name: #port; 
		presentation: presentation. 
	self assert: port = (presentation pane port: #port). 
	self assert: (presentation pane port: #port) = port. 
	self assert: port hash = (presentation pane port: #port) hash. 
	self assert: (presentation pane port: #port) hash = port hash! !

!GLMPortTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testSimplePort 
	 
	| port | 
	port := GLMSimplePort new. 
	port name: #foo. 
	port value: 42. 
	self assert: port name = #foo. 
	self assert: port value = 42. 
	self assert: port hasPane not! !

TestCase subclass: #GLMPresentationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GLMPresentationTest methodsFor: 'testing' stamp: 'tg 12/31/2009 02:27'!
expectedFailures
	^ #("testUpdateYourselfOnEntityUpdate testUpdateYourselfOnPortsUpdate testUpdateYourselfOnSelectionUpdate")! !

!GLMPresentationTest methodsFor: 'tests' stamp: 'jorge.ressia 6/2/2009 23:44'!
testAnnouncement 
	 
	| pane presentation announcement | 
	pane := GLMPane named: 'test'. 
	presentation := GLMPresentation new. 
	pane addPresentation: presentation. 
	announcement := nil. 
	presentation 
		when: GLMContextChanged 
		do: [:ann | announcement := ann]. 
	(pane port: #entity) value: 42. 
	self assert: announcement notNil. 
	self assert: announcement property = #entity. 
	self assert: announcement value = 42! !

!GLMPresentationTest methodsFor: 'tests' stamp: 'jorge.ressia 6/2/2009 23:44'!
testContext 
	 
	| pane presentation | 
	pane := GLMPane named: 'test'. 
	presentation := GLMPresentation new. 
	pane addPresentation: presentation. 
	presentation selection: 42. 
	self assert: (pane port: #selection) value = 42. 
	(pane port: #entity) value: 'foo'. 
	self assert: presentation entity = 'foo'! !

!GLMPresentationTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testDisplay 
	 
	| presentation | 
	presentation := GLMPresentation new. 
	presentation entity: #foo. 
	self assert: presentation displayValue = #foo. 
	presentation entity: #(#foo #bar). 
	self assert: presentation displayValue = #(#foo #bar). 
	presentation entity: (GLMMultiValue withAll: #(#foo #bar)). 
	self assert: presentation displayValue = #foo. 
	presentation transformation: [:first :second | (first , second) asSymbol]. 
	self assert: presentation displayValue = #foobar! !

!GLMPresentationTest methodsFor: 'tests' stamp: 'tg 12/31/2009 00:24'!
testExplicitNotNilMultipleValues
	| presentation | 
	presentation := GLMPresentation new. 
	presentation useExplicitNotNil.
	(presentation pane port: #entity) value: (GLMMultiValue withAll: #(nil nil)).
	self assert: presentation matches not.
	(presentation pane port: #entity) value: (GLMMultiValue withAll: #(1 nil)).
	self assert: presentation matches.
	(presentation pane port: #entity) value: (GLMMultiValue withAll: #(nil 1)).
	self assert: presentation matches.
	(presentation pane port: #entity) value: (GLMMultiValue withAll: #(1 2)).
	self assert: presentation matches.! !

!GLMPresentationTest methodsFor: 'tests' stamp: 'tg 12/16/2009 17:49'!
testImplicitNotNilMultipleValues
	| presentation | 
	presentation := GLMPresentation new. 
	presentation useImplicitNotNil.
	(presentation pane port: #entity) value: (GLMMultiValue withAll: #(nil nil)).
	self assert: presentation matches not.
	(presentation pane port: #entity) value: (GLMMultiValue withAll: #(1 nil)).
	self assert: presentation matches not.
	(presentation pane port: #entity) value: (GLMMultiValue withAll: #(nil 1)).
	self assert: presentation matches not.
	(presentation pane port: #entity) value: (GLMMultiValue withAll: #(1 2)).
	self assert: presentation matches.! !

!GLMPresentationTest methodsFor: 'tests' stamp: 'tg 12/31/2009 00:29'!
testMatching 
	 
	| presentation | 
	presentation := GLMPresentation new. 
	self assert: presentation usesImplicitNotNil. 
	(presentation pane port: #entity) value: (GLMMultiValue withAll: #(nil 1)). 
	self assert: presentation matches not.
	(presentation pane port: #entity) value: 1. 
	self assert: presentation matches. 
	presentation useExplicitNotNil. 
	self assert: presentation usesImplicitNotNil not. 
	(presentation pane port: #entity) value: (GLMMultiValue withAll: #(nil 1)). 
	self assert: presentation matches. 
	(presentation pane port: #entity) value: 1. 
	self assert: presentation matches. 
	presentation condition: [:x | x > 1]. 
	presentation useImplicitNotNil. 
	self assert: presentation usesImplicitNotNil. 
	(presentation pane port: #entity) value: nil. 
	self assert: presentation matches not. 
	(presentation pane port: #entity) value: 1. 
	self assert: presentation matches not. 
	(presentation pane port: #entity) value: 2. 
	self assert: presentation matches. 
	presentation useExplicitNotNil. 
	(presentation pane port: #entity) value: 1. 
	self assert: presentation matches not. 
	(presentation pane port: #entity) value: 2. 
	self assert: presentation matches. 
	self assert: presentation usesImplicitNotNil not. 
	[(presentation pane port: #entity) value: (GLMMultiValue withAll: #(nil 1)). 
	presentation matches. 
	self signalFailure: 'Should have raised error'] 
		on: MessageNotUnderstood 
		do: 
			[:err |  
			self assert: err message selector = #>. 
			self assert: err message arguments = (Array with: 1)]! !

!GLMPresentationTest methodsFor: 'tests' stamp: 'tg 1/5/2010 21:08'!
testSetup
	| presentation |
	presentation := GLMPresentation new. 
	self assert: presentation pane notNil. 
	self assert: (presentation pane presentations includes: presentation)! !

!GLMPresentationTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testTitle 
	 
	| presentation | 
	presentation := GLMPresentation new. 
	presentation entity: #foo. 
	self assert: presentation titleValue = 'foo'. 
	presentation entity: '4'. 
	presentation title: [:x | x , '2']. 
	self assert: presentation titleValue = '42'. 
	presentation entity: (GLMMultiValue withAll: #('4' '3')). 
	presentation title: [:first :second | first , second]. 
	self assert: presentation titleValue = '43'! !

!GLMPresentationTest methodsFor: 'tests' stamp: 'tg 8/25/2009 16:01'!
testToSend
	| presentation |
	presentation := GLMPresentation new.
	presentation selection: #foo.
	self assert: presentation selection = #foo.
	presentation selection: #(#foo #bar ).
	self assert: presentation selection = #(#foo #bar ).
	presentation selection: (GLMMultiValue withAll: #(#foo #bar )).
	self assert: presentation selection = #foo.
	presentation selectionTransformation: [ :first :second | (first , second) asSymbol ].
	presentation selection: (GLMMultiValue withAll: #(#foo #bar )).
	self assert: presentation selection = #foobar! !

!GLMPresentationTest methodsFor: 'tests' stamp: 'tg 12/31/2009 03:27'!
testUpdateYourselfOnPortsUpdate
	| pane port presentation timesTriggered announcer col |
	col := OrderedCollection with: 1 with: 2. 
	pane := GLMPane named: 'test'. 
	presentation := GLMListPresentation new.
	announcer := Announcer new.
	pane addPresentation: presentation.
	presentation updateYourselfOn: TestAnnouncement from: [ announcer ].
	presentation entity: col.
	presentation shouldValidate: true.
	presentation registerAnnouncements.
	presentation selection: 2.
	self assert: presentation selection = 2.
	col removeLast.
	announcer announce: TestAnnouncement.
	self assert: presentation selection isNil
! !

!GLMPresentationTest methodsFor: 'tests' stamp: 'tg 11/8/2009 00:35'!
testUpdateYourselfOnTriggered
	| pane port presentation timesTriggered announcer | 
	pane := GLMPane named: 'test'. 
	presentation := GLMPresentation new.
	announcer := Announcer new.
	pane addPresentation: presentation.
	timesTriggered := 0.
	presentation when: GLMPresentationUpdated do: [:announcement | timesTriggered := timesTriggered + 1].

	presentation updateYourselfOn: TestAnnouncement from: #yourself.
	presentation entity: announcer.
	presentation registerAnnouncements.
	
	announcer announce: TestAnnouncement.
	self assert: timesTriggered = 1
! !

!GLMPresentationTest methodsFor: 'tests' stamp: 'JorgeRessia 11/6/2009 13:00'!
testValidate
	 
	| pane port presentation| 
	pane := GLMPane named: 'test'. 
	presentation := GLMPresentation new.
	pane addPresentation: presentation.
	presentation entity: (OrderedCollection with: 1 with: 2).
	self assert: (presentation validate: 1 on: (pane port: #foo)).
	self assert: (presentation validate: 2 on: (pane port: #foo)).
	self assert: (presentation validate: 5 on: (pane port: #foo))
! !

TestCase subclass: #GLMScriptingTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GLMScriptingTest methodsFor: 'testing' stamp: 'tg 1/5/2010 17:28'!
expectedFailures
	^ #(#testPublishingToOutsideFinder)! !

!GLMScriptingTest methodsFor: 'tests' stamp: 'tg 11/16/2009 15:11'!
testActionDefinition 
	| browser | 
	browser := GLMTabulator new. 
	browser column: #one. 
	browser showOn: #one; using: [
		browser text act: [] entitled: ''.
		browser list act: [] entitled: ''.
		browser tree act: [] entitled: '']. 
	browser startOn: #(42).
	browser panes first presentations do: [:each | 
		self assert: each actions size = 1]! !

!GLMScriptingTest methodsFor: 'tests' stamp: 'tg 12/16/2009 21:36'!
testAllowNil
	| browser presentationsChanged matchingPresentationsChanged |
	browser := GLMTabulator new.
	browser 
		column: [: c | c row: #one; row: #two];
		column: #details.
	browser showOn: #one; using: [
		browser tree display: #(1 2 3)].
	browser showOn: #two; using: [
		browser tree display: #(a b c)].
	browser showOn: #details; from: #one; from: #two; using: [
		browser text 
			display: [ :one :two | one asString, two asString];
			allowNil ].
	browser startOn: 42.
	(browser paneNamed: #details) whenPresentationsChanged: [:a | presentationsChanged := true ].
	(browser paneNamed: #details) whenMatchingPresentationsChanged: [:a | matchingPresentationsChanged := true ].
	presentationsChanged := false.
	matchingPresentationsChanged := false.

	((browser paneNamed: #one) port: #selection) value: 2.
	self assert: presentationsChanged.
	self assert: matchingPresentationsChanged.
	self assert: ((browser paneNamed: #details) presentations first) displayValue = '2nil'.
	presentationsChanged := false.

	((browser paneNamed: #two) port: #selection) value: #c.
	self assert: presentationsChanged.
	self assert: matchingPresentationsChanged.
	self assert: ((browser paneNamed: #details) presentations first) displayValue = '2c'.
	presentationsChanged := false.

	((browser paneNamed: #one) port: #selection) value: nil.
	self assert: presentationsChanged.
	self assert: matchingPresentationsChanged.
	self assert: ((browser paneNamed: #details) presentations first) displayValue = 'nilc'.! !

!GLMScriptingTest methodsFor: 'tests' stamp: 'tg 12/16/2009 21:00'!
testComplexFinderBrowser 
	 
	| browser | 
	browser := GLMFinder new. 
	browser list
		title: 'Presentation1'; 
		display: [:each | 1 to: each]. 
	browser 
		fromPrevious: #selection; 
		passivelyFromPrevious: #highlight; 
		using: [
			browser list
				title: 'Presentation2'; 
				display: [:selection :highlight | 1 to: selection + highlight]]. 
	browser startOn: 42. 
	self assert: browser presentations size = 1. 
	self assert: browser presentations first title = 'Presentation1'. 
	self assert: browser transmissions size = 1. 
	self assert: browser transmissions last origins size = 2. 
	self assert: browser transmissions last presentations size = 1. 
	self assert: browser transmissions last presentations first title = 'Presentation2'. 
	self assert: (browser panes first port: #entity) value = 42. 
	(browser panes first port: #highlight) value: 43. 
	(browser panes first port: #selection) value: 41. 
	self assert: browser panes size = 2. 
	self assert: browser panes last presentations last displayValue size = 84. 
	self assert: browser panes last presentations size = 2! !

!GLMScriptingTest methodsFor: 'tests' stamp: 'tg 1/5/2010 16:18'!
testConditionalPresentation 
	 
	| browser | 
	browser := GLMTabulator new. 
	browser column: #one; column: #two. 
	browser showOn: #two; from: #one; using: [
		browser text when: [:x | x = 42]. 
		browser list when: [:x | x > 42]]. 
	((browser paneNamed: #one) port: #selection) value: 42. 
	self assert: (browser paneNamed: #two) matchingPresentations size = 1. 
	self assert: ((browser paneNamed: #two) matchingPresentations first isKindOf: 
					GLMTextPresentation). 
	((browser paneNamed: #one) port: #selection) value: 43. 
	self assert: (browser paneNamed: #two) matchingPresentations size = 1. 
	self assert: ((browser paneNamed: #two) matchingPresentations first isKindOf: 
					GLMListPresentation)! !

!GLMScriptingTest methodsFor: 'tests' stamp: 'tg 11/16/2009 15:11'!
testDynamicActions
	| browser |
	browser := GLMTabulator new.
	browser column: #one.
	browser
		showOn: #one;
		using: [ browser list
				display: [ :x | 1 to: x ];
				actions: [ :list | 
					(1 to: list selection) collect: 
						[ :index | 
						GLMAction new
							action: [ index ];
							title: 'Action' , index printString;
							yourself ] ] ].
	browser startOn: 42.
	(browser panes first port: #selection) value: 3.
	self assert: browser panes first presentations first dynamicActions size = 3.
	(browser panes first port: #selection) value: 5.
	self assert: browser panes first presentations first dynamicActions size = 5! !

!GLMScriptingTest methodsFor: 'tests' stamp: 'tg 11/16/2009 15:11'!
testEntityInUpdateAction 
	 
	| browser inputFromActionBlock | 
	browser := GLMTabulator new. 
	browser column: #one. 
	browser 
		showOn: #one; 
		using: 
				[browser text 
						update: #foo 
						on: $m 
						with: [:list :input | inputFromActionBlock := input]]. 
	browser startOn: 42. 
	browser panes first presentations first actions first 
		actOn: browser panes first presentations first. 
	self assert: inputFromActionBlock = 42! !

!GLMScriptingTest methodsFor: 'tests' stamp: 'tg 11/20/2009 00:24'!
testNestedBrowserEntity
	 
	| browser innerBrowser | 
	browser := GLMTabulator new. 
	browser column: #one. 
	innerBrowser := GLMTabulator new. 
	innerBrowser column: #innerOne. 
	innerBrowser 
		showOn: #innerOne;
		from: #outer->#entity;
		using: [innerBrowser text]. 
	browser 
		showOn: #one; 
		using: [
			(browser custom: innerBrowser)
				display: [:x | x + 2 ]]. 
	browser startOn: 40. 
	self assert: ((browser paneNamed: #one) port: #entity) value = 40. 
	self assert: (innerBrowser pane port: #entity) value = 40.
	self assert: ((innerBrowser paneNamed: #innerOne) port: #entity) value = 42.! !

!GLMScriptingTest methodsFor: 'tests' stamp: 'tg 11/20/2009 00:36'!
testNestedBrowserOther
	 
	| browser innerBrowser | 
	browser := GLMTabulator new.
	browser column: #one; column: #two. 
	innerBrowser := GLMTabulator new. 
	innerBrowser column: #innerOne. 
	innerBrowser 
		showOn: #innerOne;
"		from: #outer->#entity;"
		using: [innerBrowser text].
	innerBrowser sendToOutside: #selection from: #innerOne.
	browser showOn: #one; using: [
		(browser custom: innerBrowser)
			display: [:x | x + 2 ]]. 
	browser showOn: #two; from: #one; using: [browser text].
	browser startOn: 40. 
	self assert: ((browser paneNamed: #one) port: #entity) value = 40. 
	self assert: (innerBrowser pane port: #entity) value = 40.
	self assert: ((innerBrowser paneNamed: #innerOne) port: #entity) value = 42.
	(innerBrowser panes first port: #selection) value: 7.
	self assert: (innerBrowser pane port: #selection) value = 7.
	self assert: (browser panes last port: #entity) value = 7.! !

!GLMScriptingTest methodsFor: 'tests' stamp: 'tg 11/16/2009 15:11'!
testNestedBrowserWithExplicitTransmission 
	 
	| browser innerBrowser | 
	browser := GLMTabulator new. 
	browser column: #one. 
	innerBrowser := GLMTabulator new. 
	innerBrowser column: #innerOne. 
	innerBrowser 
		showOn: #innerOne; 
		from: #outer -> #entity; 
		using: [innerBrowser text]. 
	browser 
		showOn: #one; 
		using: [browser custom: innerBrowser]. 
	browser startOn: 42. 
	self assert: ((browser paneNamed: #one) port: #entity) value = 42. 
	self 
		assert: ((innerBrowser paneNamed: #innerOne) port: #entity) value = 42! !

!GLMScriptingTest methodsFor: 'tests' stamp: 'tg 12/1/2009 15:15'!
testOuterEntity 
	| browser innerBrowser | 
	browser := GLMTabulator new.
	browser column: #one; column: #two. 
	browser showOn: #one; using: [browser text]. 
	browser showOn: #two; fromOutside: #entity; using: [browser text].
	browser startOn: 42.
	self assert: browser transmissions first origins anyOne name = #entity.
	self assert: browser transmissions last origins anyOne name = #entity.
	self assert: browser transmissions size = 2.
	! !

!GLMScriptingTest methodsFor: 'tests' stamp: 'tg 11/16/2009 15:11'!
testPublishing 
	 
	| browser | 
	browser := GLMTabulator new. 
	browser column: #classes. 
	browser 
		sendToOutside: #selectedClass 
		from: #classes -> #selection. 
	browser 
		sendTo: #classes -> #highlight 
		fromOutside: #highlightedClass. 
	(browser panes first port: #selection) value: 42. 
	self assert: (browser pane port: #selectedClass) value = 42. 
	self assert: (browser panes first port: #selection) value = 42. 
	(browser pane port: #highlightedClass) value: 43. 
	self assert: (browser pane port: #highlightedClass) value = 43. 
	self assert: (browser panes first port: #highlight) value = 43. 
	(browser panes first port: #highlight) value: 44. 
	self assert: (browser pane port: #highlightedClass) value = 43. 
	self assert: (browser panes first port: #highlight) value = 44. 
	(browser pane port: #selectedClass) value: 45. 
	self assert: (browser pane port: #selectedClass) value = 45. 
	self assert: (browser panes first port: #selection) value = 42! !

!GLMScriptingTest methodsFor: 'tests' stamp: 'tg 12/31/2009 03:19'!
testPublishingToOutsideFinder
	| innerBrowser finder | 
	finder := GLMFinder new.
	innerBrowser := GLMTabulator new.
	innerBrowser column: #any.
	innerBrowser showOn: #any; using: [ innerBrowser list display: [:x | 1 to: 43 ] ].
	innerBrowser
		sendToOutside: #selection
		from: #any -> #selection.
	finder custom: innerBrowser.
	finder startOn: 43.
	self assert: (finder panes first port: #entity) value = 43.
	self assert: (finder panes first port: #selection) value isNil.
	((finder panes first presentations first paneNamed: #any) port: #selection) value: 42.
	self assert: (finder panes first port: #selection) value = 42.
	self assert: (finder panes first port: #entity) value = 43.
	self assert: finder panes size = 2.
	self assert: (finder panes last port: #entity) value = 42.
	
	self assert: (finder panes first presentations first isKindOf: GLMTabulator).
	self assert: (finder panes last presentations first isKindOf: GLMTabulator).
	self assert: (finder panes first presentations first isKindOf: GLMTabulator).
	! !

!GLMScriptingTest methodsFor: 'tests' stamp: 'tg 11/19/2009 23:07'!
testReferences
	| browser pane1 | 
	browser := GLMExplicitBrowser new.  
 	pane1 := browser addNewPaneNamed: #pane1.
	self assert: (browser resolveOriginPort: #pane1) == (pane1 port: #selection). 
	self assert: (browser resolveOriginPort: #pane1 -> #foo) == (pane1 port: #foo). 
	self assert: (browser resolveDestinationPort: #pane1) == (pane1 port: #entity). 
	self assert: (browser resolveDestinationPort: #pane1 -> #foo) == (pane1 port: #foo). 
	self assert: ((browser resolveOriginPort: #outer) isKindOf: GLMParentPort). 
	self assert: (browser resolveOriginPort: #outer) presentation == browser. 
	self assert: (browser resolveOriginPort: #outer) name = #selection. 
	self assert: ((browser resolveOriginPort: #outer -> #foo) isKindOf: GLMParentPort). 
	self assert: (browser resolveOriginPort: #outer -> #foo) presentation == browser. 
	self assert: (browser resolveOriginPort: #outer -> #foo) name = #foo. 
	self assert: ((browser resolveDestinationPort: #outer) isKindOf: GLMParentPort). 
	self assert: (browser resolveDestinationPort: #outer) presentation == browser. 
	self assert: (browser resolveDestinationPort: #outer) name = #entity. 
	self assert: ((browser resolveDestinationPort: #outer -> #foo) isKindOf: GLMParentPort). 
	self assert: (browser resolveDestinationPort: #outer -> #foo) presentation == browser. 
	self assert: (browser resolveDestinationPort: #outer -> #foo) name = #foo! !

!GLMScriptingTest methodsFor: 'tests' stamp: 'TestRunner 11/20/2009 01:03'!
testScriptingDefaults 
	 
	| browser | 
	browser := GLMTabulator new. 
	browser startOn: 42. 
	self assert: browser panes size = 1. 
	self assert: browser transmissions size = 1.
	self assert: browser transmissions first origins first
				= (browser pane port: #entity).
	self assert: browser transmissions first destination 
				= (browser panes first port: #entity)! !

!GLMScriptingTest methodsFor: 'tests' stamp: 'tg 11/16/2009 15:11'!
testSimpleTransmission 
	 
	| browser | 
	browser := GLMTabulator new. 
	browser 
		column: #one; 
		column: #two. 
	browser 
		sendTo: #two -> #port2 
		from: #one -> #port1. 
	self assert: browser transmissions size = 1. 
	self assert: (browser transmissions first isKindOf: GLMSimpleTransmission). 
	self 
		assert: 
			browser transmissions first origin 
				= ((browser paneNamed: #one) port: #port1). 
	self 
		assert: 
			browser transmissions first destination 
				= ((browser paneNamed: #two) port: #port2)! !

!GLMScriptingTest methodsFor: 'tests' stamp: 'tg 12/29/2009 16:49'!
testSimpleTransmissionsToOuter
	 
	| browser | 
	browser := GLMTabulator new. 
	browser column: #one. 
	browser sendTo: #outer->#increased from: #outer->#entity with: [ :x | x + 1 ].
	browser showOn: #one; from: #outer->#increased; using: [browser text].
	browser startOn: 41.
	self assert: ((browser paneNamed: #one) port: #entity) value = 42
! !

!GLMScriptingTest methodsFor: 'tests' stamp: 'TestRunner 11/20/2009 00:51'!
testStartTransmission 
	 
	| browser | 
	browser := GLMTabulator new. 
	browser 
		column: #one; 
		column: #two. 
	browser 
		showOn: #one; 
		using: [browser list]. 
	self assert: browser transmissions size = 1.
	self assert: (browser paneNamed: #one) presentations isEmpty. 
	self assert: (browser paneNamed: #two) presentations isEmpty. 
	browser startOn: 15. 
	self assert: (browser paneNamed: #one) presentations size = 1. 
	self assert: (browser paneNamed: #two) presentations isEmpty! !

!GLMScriptingTest methodsFor: 'tests' stamp: 'TestRunner 11/20/2009 00:51'!
testStartWithOnlyJumpStart 
	 
	| browser | 
	browser := GLMTabulator new. 
	browser 
		column: #one; 
		column: #two. 
	browser 
		showOn: #one; 
		using: [browser list]. 
	browser 
		showOn: #two; 
		from: #one; 
		using: [browser text]. 
	self assert: browser transmissions size = 2.
	self assert: (browser paneNamed: #one) presentations isEmpty. 
	self assert: (browser paneNamed: #two) presentations isEmpty. 
	browser startOn: #(15 25 35). 
	self assert: (browser paneNamed: #one) presentations size = 1. 
	self assert: (browser paneNamed: #one) matchingPresentations size = 1. 
	self assert: (browser paneNamed: #two) presentations isEmpty. 
	self assert: (browser paneNamed: #two) matchingPresentations isEmpty! !

!GLMScriptingTest methodsFor: 'tests' stamp: 'tg 11/20/2009 01:08'!
testThreePanesTransmissions 
	 
	| browser one two | 
	browser := GLMTabulator new. 
	browser 
		column: #one; 
		column: #two; 
		column: #three. 
	browser 
		showOn: #three; 
		from: #one; 
		passivelyFrom: #two; 
		using: 
				[browser text 
						display: 
							[:x :y |  
							one := x. 
							two := y]]. 
	self assert: browser transmissions size = 1. 
	self assert: browser transmissions first passiveOrigins size = 1. 
	self assert: browser transmissions first activeOrigins size = 1. 
	((browser paneNamed: #two) port: #selection) value: 15. 
	self assert: ((browser paneNamed: #two) port: #selection) value = 15. 
	self assert: ((browser paneNamed: #three) port: #entity) value isNil. 
	((browser paneNamed: #one) port: #selection) value: 20. 
	self assert: ((browser paneNamed: #one) port: #selection) value = 20. 
	self assert: ((browser paneNamed: #three) port: #entity) value first = 20. 
	self assert: ((browser paneNamed: #three) port: #entity) value last = 15! !

!GLMScriptingTest methodsFor: 'tests' stamp: 'tg 11/16/2009 15:11'!
testTransmissionWithTwoOrigins 
	 
	| browser | 
	browser := GLMTabulator new. 
	browser 
		column: #one; 
		column: #two; 
		column: #three. 
	browser 
		showOn: #three; 
		from: #one; 
		from: #two; 
		using: [browser text]. 
	((browser paneNamed: #one) port: #selection) value: 42. 
	self assert: ((browser paneNamed: #three) port: #entity) value first = 42. 
	self assert: ((browser paneNamed: #three) port: #entity) value last = nil. 
	self assert: (browser paneNamed: #three) presentations size = 1. 
	self assert: (browser paneNamed: #three) matchingPresentations size = 0. 
	((browser paneNamed: #two) port: #selection) value: 43. 
	self assert: ((browser paneNamed: #three) port: #entity) value first = 42. 
	self assert: ((browser paneNamed: #three) port: #entity) value last = 43. 
	self assert: (browser paneNamed: #three) matchingPresentations size = 1! !

!GLMScriptingTest methodsFor: 'tests' stamp: 'tg 11/20/2009 01:09'!
testTwoTransmissionsWithOnlyOneEvent 
	 
	| browser | 
	browser := GLMTabulator new. 
	browser 
		column: #one; 
		column: #two; 
		column: #three. 
	browser 
		showOn: #two; 
		from: #one; 
		using: [browser list]. 
	browser 
		showOn: #three; 
		from: #two; 
		using: [browser text]. 
	self assert: browser transmissions size = 2. 
	self assert: (browser paneNamed: #one) presentations isEmpty. 
	self assert: (browser paneNamed: #two) presentations isEmpty. 
	self assert: (browser paneNamed: #three) presentations isEmpty. 
	((browser paneNamed: #one) port: #selection) value: 42. 
	self assert: ((browser paneNamed: #two) port: #entity) value = 42. 
	self assert: (browser paneNamed: #one) presentations isEmpty. 
	self assert: (browser paneNamed: #two) presentations size = 1. 
	self assert: (browser paneNamed: #two) matchingPresentations size = 1. 
	self assert: (browser paneNamed: #three) presentations isEmpty. 
	self assert: (browser paneNamed: #three) matchingPresentations isEmpty! !

!GLMScriptingTest methodsFor: 'tests' stamp: 'tg 11/16/2009 15:11'!
testUpdateAction 
	 
	| browser | 
	browser := GLMTabulator new. 
	browser column: #one; column: #two. 
	browser showOn: #one; using: [
		browser list update: #foo on: $m with: [:list :input | 42]]. 
	browser showOn: #two; from: #one -> #foo; using: [browser text]. 
	browser startOn: #(1 2 3). 
	self assert: browser panes first presentations size = 1. 
	self assert: browser panes last presentations isEmpty. 
	browser panes first presentations first actions first 
		actOn: browser panes first presentations first. 
	self assert: browser panes second presentations size = 1. 
	self assert: browser panes second presentations first entity = 42! !

!GLMScriptingTest methodsFor: 'tests' stamp: 'tg 12/31/2009 03:17'!
testUpdateYourselfOn

	| announcer entity browser presentation |
	announcer := Announcer new.
	entity := OrderedCollection with: 1 with: 2 with: 3.
	browser := GLMTabulator new.
	browser column: #one.
	browser showOn: #one; using: [
		presentation := browser list 
			updateYourselfOn: TestAnnouncement from: [ announcer ];
			shouldValidate: true ].
	browser startOn: entity.
	presentation registerAnnouncements.
	presentation selection: 3.
	entity removeLast.
	announcer announce: TestAnnouncement.
	self assert: presentation selection isNil ! !

TestCase subclass: #GLMSimpleTransmissionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GLMSimpleTransmissionTest methodsFor: 'tests' stamp: 'jorge.ressia 6/2/2009 23:45'!
testSimple 
	 
	| pane1 pane2 transmission | 
	pane1 := GLMPane named: 'test1'. 
	pane2 := GLMPane named: 'test2'. 
	transmission := (GLMSimpleTransmission new) 
		origin: (pane1 port: #output); 
		destination: (pane2 port: #input); 
		yourself. 
	(pane1 port: #output) value: 42. 
	self assert: (pane1 port: #output) value = 42. 
	self assert: (pane2 port: #input) value = nil. 
	transmission transmit. 
	self assert: (pane1 port: #output) value = 42. 
	self assert: (pane2 port: #input) value = 42! !

!GLMSimpleTransmissionTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testTriggerConditions 
	"Tests that the transmission is triggered only when the origin changes." 
	 
	| transmission port1 port2 | 
	transmission := GLMSimpleTransmission new. 
	port1 := GLMPort new name: #port1. 
	port2 := GLMPort new name: #port2. 
	transmission origin: port1. 
	transmission destination: port2. 
	self assert: (transmission originatesAt: port1). 
	self assert: (transmission originatesAt: port2) not. 
	self assert: (transmission originatesAt: GLMPort new) not! !

!GLMSimpleTransmissionTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testTriggerConditionsWithParentPort 
	 
	| transmission presentation | 
	transmission := GLMSimpleTransmission new. 
	presentation := GLMPresentation new. 
	transmission 
		origin: 
			((GLMParentPort new) 
				presentation: presentation; 
				name: #port1; 
				yourself). 
	self 
		assert: 
			(transmission 
				originatesAt: 
					((GLMParentPort new) 
						presentation: presentation; 
						name: #port1; 
						yourself)). 
	self assert: (transmission originatesAt: (presentation pane port: #port1))! !

TestCase subclass: #GLMTableLayoutTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GLMTableLayoutTest methodsFor: 'tests' stamp: 'tg 11/16/2009 15:11'!
testComplex 
	 
	| layout | 
	layout := GLMTabulator new. 
	layout 
		addColumn: 
			[:column |  
			column addRow: #second. 
			column addRow: #third. 
			column addRow: #fourth. 
			column 
				addRow: 
					[:row |  
					row addColumn: #fifth. 
					row addColumn: #sixth]]. 
	layout addColumn: #first. 
	self assert: layout cell children size = 2. 
	self assert: layout cell children first children size = 4. 
	self assert: layout cell children first children last children size = 2! !

!GLMTableLayoutTest methodsFor: 'tests' stamp: 'tg 11/16/2009 15:11'!
testOneSimpleColumnAndOneNested 
	 
	| layout | 
	layout := GLMTabulator new. 
	layout 
		addColumn: 
			[:column |  
			column addRow: #second. 
			column addRow: #third. 
			column addRow: #fourth]. 
	layout addColumn: #first. 
	self assert: layout cell children size = 2. 
	self assert: layout cell children first children size = 3! !

!GLMTableLayoutTest methodsFor: 'tests' stamp: 'tg 11/16/2009 15:11'!
testOneSimpleRowAndOneNested 
	 
	| layout | 
	layout := GLMTabulator new. 
	layout addRow: #first. 
	layout 
		addRow: 
			[:row |  
			row addColumn: #second. 
			row addColumn: #third. 
			row addColumn: #fourth]. 
	self assert: layout cell children size = 2. 
	self assert: layout cell children last children size = 3! !

!GLMTableLayoutTest methodsFor: 'tests' stamp: 'tg 11/16/2009 15:11'!
testSimpleColumns 
	 
	| layout | 
	layout := GLMTabulator new. 
	layout addColumn: #first. 
	layout addColumn: #second. 
	self assert: layout cell children size = 2! !

!GLMTableLayoutTest methodsFor: 'tests' stamp: 'tg 11/16/2009 15:11'!
testSimpleRows 
	 
	| layout | 
	layout := GLMTabulator new. 
	layout addRow: #first. 
	layout addRow: #second. 
	self assert: layout cell children size = 2. 
	self assert: layout cell isColumn. 
	self assert: layout cell children first isRow! !

TestCase subclass: #GLMTestExtensions
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GLMTestExtensions methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testGlamourValue 
	"Block closure" 
	 
	self assert: ([#foo] glamourValue: #(1 2)) = #foo. 
	self 
		assert: ([:first | Array with: first] glamourValue: #(1 2)) = #(#(1 2)). 
	self 
		assert: 
			([:first :second | Array with: first with: second] glamourValue: #(1 2)) = 
					#(#(1 2) nil). 
	self 
		assert: 
			([:first :second | Array with: first with: second] 
				glamourValue: (GLMMultiValue with: 1 with: 2)) = #(1 2).	"Symbol" 
	self assert: (#yourself glamourValueWithArgs: #(1 2)) = 1. 
	self assert: (#yourself glamourValueWithArgs: #()) = nil	"self assert: (#yourself glamourValue: (MultiValue with: 1 with: 2)) = 1."! !

!GLMTestExtensions methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testGlamourValueWithArgs 
	"Block closure" 
	 
	self assert: ([#foo] glamourValueWithArgs: #(1 2)) = #foo. 
	self 
		assert: 
			([:first | Array with: first] glamourValueWithArgs: #(1 2)) = #(1). 
	self 
		assert: 
			([:first :second | Array with: first with: second] glamourValueWithArgs: 
					#(1 2)) = #(1 2). 
	self 
		assert: 
			([:first :second :third | Array with: first with: second with: third] 
				glamourValueWithArgs: #(1 2)) = #(1 2 nil).	"Symbol" 
	self assert: (#yourself glamourValueWithArgs: #(1 2)) = 1. 
	self assert: (#yourself glamourValueWithArgs: #()) = nil! !

TestCase subclass: #GLMTextPresentationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GLMTextPresentationTest methodsFor: 'testing' stamp: 'tg 8/7/2009 01:25'!
testSelectedText
	| presentation |
	presentation := GLMTextPresentation new.
	self assert: (presentation selectedText = '').
	presentation selectedTextBlock: ['selection'].
	self assert: (presentation selectedText = 'selection')! !

TestCase subclass: #GLMTransmissionContextTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GLMTransmissionContextTest methodsFor: 'testing' stamp: 'tg 12/19/2009 00:06'!
testCopy
	| context copy |
	context := GLMTransmissionContext new.
	context addPort: GLMSimplePort new.
	copy := context copy.
	self assert: copy ~~ context.
	self assert: copy ports = context ports.
	self assert: copy ports ~~ context ports.
! !

!GLMTransmissionContextTest methodsFor: 'testing' stamp: 'tg 12/19/2009 00:26'!
testForbiddenAnnouncements
	| context pane |
	context := GLMTransmissionContext new.
	pane := GLMPane new.
	self assert: (context canAnnounceMatchingPresentationsChanged: pane).
	context forbidToAnnounceMatchingPresentationsChanged: pane.
	self assert: (context canAnnounceMatchingPresentationsChanged: pane) not! !

!GLMTransmissionContextTest methodsFor: 'testing' stamp: 'tg 12/19/2009 00:07'!
testInclues
	| context port |
	port := GLMSimplePort new.
	context := GLMTransmissionContext new.
	context addPort: port.
	self assert: (context includesPort: port)! !

TestCase subclass: #GLMTreePresentationTest
	instanceVariableNames: 'pane presentation'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GLMTreePresentationTest methodsFor: 'tests' stamp: 'tg 11/15/2009 23:53'!
setUp
	pane := GLMPane named: 'test'.
	presentation := GLMTreePresentation new.
	pane addPresentation: presentation.
	presentation entity: #(($a $b $c $d) ($e $f) ($g)).
	presentation children: [:x :i | x asString size > 1 ifTrue: [x] ifFalse: [OrderedCollection new]].
	presentation shouldValidate: true.! !

!GLMTreePresentationTest methodsFor: 'tests' stamp: 'tg 11/15/2009 17:06'!
testValidateOn
	self assert: (presentation validate: #($e $f) on: (pane port: #selection)).
	self assert: (presentation validate: $a on: (pane port: #selection)).
	self deny: (presentation validate: $h on: (pane port: #selection))! !

!GLMTreePresentationTest methodsFor: 'tests' stamp: 'tg 11/15/2009 17:06'!
testValidatePorts
	presentation selection: #($e $f).
	self assert: presentation selection = #($e $f).
	presentation selection: $a.
	self assert: presentation selection = $a.
	presentation selection: 'wrongSelection'."this should be invalid"
	self assert: presentation selection = $a! !

GLMPane subclass: #GLMTestPane
	instanceVariableNames: 'seenTransmissions'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GLMTestPane classSide methodsFor: 'private' stamp: 'jorge.ressia 6/3/2009 08:55'!
new

	^super new initialize! !

!GLMTestPane classSide methodsFor: 'private' stamp: ' 4/5/09 22:18'!
portClass 
	 
	^GLMTestPort! !

!GLMTestPane methodsFor: 'accessing' stamp: 'jorge.ressia 6/2/2009 23:35'!
browser

	browser isNil ifTrue: [^GLMNoBrowser new].
	^browser! !

!GLMTestPane methodsFor: 'accessing' stamp: 'jorge.ressia 6/2/2009 21:37'!
browser: aBrowser 
	browser := aBrowser! !

!GLMTestPane methodsFor: 'accessing' stamp: 'jorge.ressia 6/3/2009 08:57'!
initialize

	ports := OrderedCollection new.
	presentations := OrderedCollection new.! !

GLMPanePort subclass: #GLMTestPort
	instanceVariableNames: 'seenTransmissions'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GLMTestPort methodsFor: 'accessing' stamp: ' 4/5/09 22:18'!
receive: aTransmission 
	 
	self seenTransmissions addLast: aTransmission. 
	^super receive: aTransmission! !

!GLMTestPort methodsFor: 'accessing' stamp: 'jre 9/18/2009 21:47'!
receive: aTransmission in: aContext
	 
	self seenTransmissions addLast: aTransmission. 
	^super receive: aTransmission in: aContext! !

!GLMTestPort methodsFor: 'accessing' stamp: ' 4/5/09 22:18'!
seenTransmissions 
	 
	^seenTransmissions ifNil: [seenTransmissions := OrderedCollection new]! !

Announcement subclass: #TestAnnouncement
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

Object subclass: #GlamourousBenchmark
	instanceVariableNames: 'progressBarSize progress'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GlamourousBenchmark methodsFor: 'as yet unclassified' stamp: 'Alexandre Bergel 10/23/2009 10:22'!
actionsFor: aPresentation 
	|actions|
	aPresentation isMultiple 
							ifTrue: [actions := (aPresentation selection) ifNil: [OrderedCollection new]]
							ifFalse: [actions := OrderedCollection with: aPresentation selection ].
	^ actions collect: [:i |
					(GLMAction new) 
						action: [:each | Transcript show: 'Menu - Item', i printString; cr]; 
						title: 'Menu - Item', i printString; 
						yourself ]! !

!GlamourousBenchmark methodsFor: 'as yet unclassified' stamp: 'tg 11/16/2009 15:11'!
defaultBrowser 
	| browser |
	browser := GLMTabulator new.
	browser column: #one; column: #two.

	browser showOn: #one; using: [
		browser list
			display: [:x | 1 to: x * 3]].
	browser showOn: #two; from: #one; using: [
		browser list
			display: [:x | 1 to: x * 3]].
	browser showOn: #one; from: #two; using: [
		browser list
			display: [:x | 1 to: x * 3]].

	^ browser! !

!GlamourousBenchmark methodsFor: 'as yet unclassified' stamp: 'Alexandre Bergel 10/23/2009 10:29'!
defaultFinderBrowser 
	"
	self new defaultFinderBrowser openOn: 10
	"
	| finder |
	finder := GLMFinder new.
	finder list
		title: 'title';
		display: [:each | 1 to: each ].

	^ finder! !

!GlamourousBenchmark methodsFor: 'as yet unclassified' stamp: 'Alexandre Bergel 10/23/2009 09:50'!
measureOpeningTime
	| browser numberOfOpenings time |
	numberOfOpenings := 15.

	browser := self defaultBrowser.
	time := Time millisecondsToRun: [ numberOfOpenings timesRepeat: [(browser openOn: 10) delete] ].
	^ {numberOfOpenings . time}! !

!GlamourousBenchmark methodsFor: 'as yet unclassified' stamp: 'Alexandre Bergel 10/23/2009 09:57'!
measureSelectionTime
	"
	self new measureSelectionTime 
	"
	^ self measureSelectionTimeForSize: 1000! !

!GlamourousBenchmark methodsFor: 'as yet unclassified' stamp: 'Alexandre Bergel 10/23/2009 10:04'!
measureSelectionTimeForSize: size
	"
	self new measureSelectionTime 
	"
	| browser numberOfSelections time port window |
	numberOfSelections := 15.

	browser := self defaultBrowser.
	window := browser openOn: size.
	port := browser panes first ports second.
	time := Time millisecondsToRun: [ (size - numberOfSelections) to: size do: [:i | port value: i ] ].
	window delete.
	^ {size . time}! !

!GlamourousBenchmark methodsFor: 'as yet unclassified' stamp: 'Alexandre Bergel 10/23/2009 10:32'!
measureSelectionTimeInFinderForSize: size
	"
	self new measureSelectionTimeInFinderForSize: 20 
	"
	| browser numberOfSelections time port window |

	browser := self defaultFinderBrowser.
	window := browser openOn: size.
	
	time := Time millisecondsToRun: 
			[size timesRepeat: [ (window model panes last port: #selection) value: size].].
		
	window delete.
	^ {size . time}! !

Object subclass: #GlamourousHealth
	instanceVariableNames: 'progressBarSize progress progressBarCurrentValue'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GlamourousHealth classSide methodsFor: 'as yet unclassified' stamp: 'Alexandre Bergel 10/23/2009 09:03'!
produceReport
	^ self new produceReport! !

!GlamourousHealth methodsFor: 'progress bar' stamp: 'Alexandre Bergel 10/23/2009 11:32'!
displayProgressBar: aBlock size: size titled: title

	progressBarCurrentValue := 1.
	title
		displayProgressAt: Display center
		from: 0 to: size
		during: [:bar | aBlock value: bar ]
! !

!GlamourousHealth methodsFor: 'progress bar' stamp: 'Alexandre Bergel 10/23/2009 11:32'!
incrProgressBar: bar
	progressBarCurrentValue :=  progressBarCurrentValue + 1.
	bar value: progressBarCurrentValue.
! !

!GlamourousHealth methodsFor: 'logging' stamp: 'Alexandre Bergel 10/23/2009 09:01'!
log: object named: title
	| selectorName source newSource |
	selectorName := (#log, title) asSymbol.
	(self class includesSelector: selectorName)
		ifFalse: [ self class compile: selectorName, String cr, String cr, '	^ #()', String cr.
					  self class organization classify: selectorName under: 'logging'].

	source := (self class >> selectorName) getSourceFromFile.
	newSource := source , '	,#(#(', object printString, ' ''', title, '''))'.
	self class compile: newSource.! !

!GlamourousHealth methodsFor: 'logging' stamp: 'AlexandreBergel 10/26/2009 17:39'!
logMethodCoverage

	^ #()
	,#(#(0 'MethodCoverage'))	,#(#(86.0 'MethodCoverage'))	,#(#(86.0 'MethodCoverage'))	,#(#(84.31 'MethodCoverage'))	,#(#(84.31 'MethodCoverage'))	,#(#(84.31 'MethodCoverage'))	,#(#(83.49 'MethodCoverage'))	,#(#(83.49 'MethodCoverage'))	,#(#(83.49 'MethodCoverage'))	,#(#(80.37 'MethodCoverage'))	,#(#(80.37 'MethodCoverage'))	,#(#(80.37 'MethodCoverage'))	,#(#(80.37 'MethodCoverage'))	,#(#(80.37 'MethodCoverage'))	,#(#(80.37 'MethodCoverage'))	,#(#(80.37 'MethodCoverage'))	,#(#(80.37 'MethodCoverage'))	,#(#(77.47 'MethodCoverage'))	,#(#(76.78 'MethodCoverage'))	,#(#(76.78 'MethodCoverage'))	,#(#(76.78 'MethodCoverage'))	,#(#(76.99 'MethodCoverage'))	,#(#(76.99 'MethodCoverage'))	,#(#(76.31 'MethodCoverage'))	,#(#(76.31 'MethodCoverage'))	,#(#(76.31 'MethodCoverage'))	,#(#(76.31 'MethodCoverage'))	,#(#(76.31 'MethodCoverage'))	,#(#(76.31 'MethodCoverage'))	,#(#(0.0 'MethodCoverage'))	,#(#(0.0 'MethodCoverage'))	,#(#(33.07 'MethodCoverage'))	,#(#(33.02 'MethodCoverage'))	,#(#(33.02 'MethodCoverage'))	,#(#(32.98 'MethodCoverage'))	,#(#(32.98 'MethodCoverage'))	,#(#(33.46 'MethodCoverage'))	,#(#(33.46 'MethodCoverage'))! !

!GlamourousHealth methodsFor: 'util' stamp: 'Alexandre Bergel 10/23/2009 10:35'!
openMondrianGraphOn: associations titled: titleAsString

	^ self openMondrianGraphOn: associations titled: titleAsString scaleX: 0.10! !

!GlamourousHealth methodsFor: 'util' stamp: 'Alexandre Bergel 10/23/2009 10:35'!
openMondrianGraphOn: associations titled: titleAsString scaleX: scaleXFactor

	| view |
	view := MOViewRenderer new.


	view node: #foo forIt: [
		view layout: (MOScatterplotLayout new x: #key; y: #value; scaleFactorX: scaleXFactor; scaleFactorY: 0.10 "; upSideDown").
		view interaction popupText: [:element | element key printString, ' nodes => ', element value printString, ' ms' ].
		view nodes: associations.
	
	].
	view open! !

!GlamourousHealth methodsFor: 'util' stamp: 'Alexandre Bergel 10/23/2009 09:03'!
openWorkspaceWith: stream
	Workspace new contents: (stream contents); openLabel: 'Glamour health report'.! !

!GlamourousHealth methodsFor: 'public' stamp: 'Alexandre Bergel 10/23/2009 12:46'!
produceReport
	"
	self new produceReport
	"
	| stream |
	stream := WriteStream on: String new.
	self writeGeneralInfoOn: stream.
	self writeOpeningMeasurementsOn: stream.
	self writeSelectionMeasurementsOn: stream.
	self writeSelectionInFinderMeasurementsOn: stream.
	self writeCoverageInfoOn: stream.
	
	self openWorkspaceWith: stream.
! !

!GlamourousHealth methodsFor: 'public' stamp: 'Alexandre Bergel 10/26/2009 10:32'!
viewTestCoverage
	"
	GlamourousHealth new viewTestCoverage
	"
	| typeClass coverage bar |
	typeClass := Smalltalk 
		at: #CoveragePackageSpy
		ifAbsent: 
			[ self inform: 'The coverage is realized by the tool Spy. Please download it from www.squeaksource.com/Spy.html . Skip the coverage by pressing OK'.
			^ self ].
	coverage := typeClass forPackagesMatching: 'Glamour*'.
	coverage viewBasic! !

!GlamourousHealth methodsFor: 'report producers' stamp: 'Alexandre Bergel 10/26/2009 10:32'!
writeCoverageInfoOn: stream 
	| typeClass ratioCoveredMethods testClasses lastCoverage diff diffAsString |
	typeClass := Smalltalk 
		at: #CoveragePackageSpy
		ifAbsent: 
			[ self inform: 'The coverage is realized by the tool Spy. Please download it from www.squeaksource.com/Spy.html . Skip the coverage by pressing OK'.
			^ self ].
	self 
		displayProgressBar: 
			[ :bar | 
			ratioCoveredMethods := (typeClass 
				forPackagesMatching: 'Glamour*'
				atEachTestEvaluate: [ self incrProgressBar: bar ]) ratioCoveredMethods ]
		size: (typeClass numberOfTestUnitClassesInPackagesMatching: 'Glamour*')
		titled: 'Running test for coverage'.
	stream
		nextPutAll: ratioCoveredMethods printString , '  % of methods are covered';
		cr.
	lastCoverage := self logMethodCoverage last first.
	diff := ratioCoveredMethods - lastCoverage.
	diff := ((diff * 100) asInteger / 100) asFloat.
	diffAsString := diff > 0 
		ifTrue: [ '+' , diff printString ]
		ifFalse: [ diff printString ].
	stream nextPutAll: 'Progress from last time: ' , diffAsString , ' %'.
	stream cr.
	self 
		log: ratioCoveredMethods
		named: 'MethodCoverage'! !

!GlamourousHealth methodsFor: 'util' stamp: 'Alexandre Bergel 10/23/2009 09:44'!
writeDelimitationOn: stream
	stream nextPutAll: '------------------'; cr! !

!GlamourousHealth methodsFor: 'report producers' stamp: 'AlexandreBergel 10/26/2009 16:54'!
writeGeneralInfoOn: stream
	| mcPackage |
	stream nextPutAll: 'Report produced on ', DateAndTime now printString; cr.
	
	mcPackage := MCWorkingCopy allManagers detect: [:m | m package name beginsWith: 'Glamour-Tests' ].! !

!GlamourousHealth methodsFor: 'report producers' stamp: 'Alexandre Bergel 10/23/2009 11:37'!
writeOpeningMeasurementsOn: stream
	| res |
	self writeDelimitationOn: stream.
	stream nextPutAll: 'Opening Browser Benchmark:'; cr.

	self displayProgressBar: [:bar | 
		res := GlamourousBenchmark new measureOpeningTime.
		stream nextPutAll: res first printString, ' openings => ', res second printString, ' ms'; cr.
		self incrProgressBar: bar.
		]
		size: 1
		titled: 'Opening'.
	
	self writeDelimitationOn: stream.
	stream cr.! !

!GlamourousHealth methodsFor: 'report producers' stamp: 'AlexandreBergel 10/26/2009 17:38'!
writeSelectionInFinderMeasurementsOn: stream
	| res browserSizes bench associations title |
	browserSizes := #(1 5 10 15 20 25 30 35 40 45 50).
	self writeDelimitationOn: stream.

	title := 'Selecting in finder item Benchmark'.
	stream nextPutAll: title; cr.

	associations := OrderedCollection new.
	bench := GlamourousBenchmark new.
	
	self 
		displayProgressBar:
			[:bar | 
				browserSizes do: [: size |
					res := bench 	measureSelectionTimeInFinderForSize: size.
					stream nextPutAll: res first printString, ' size and selections => ', 
											res second printString, ' ms'; cr.
					associations add: (res first -> res second).
					self incrProgressBar: bar.
			]]
		size: browserSizes size 
		titled: title.
	

	self openMondrianGraphOn: associations titled: title scaleX: 1.0.
	
	
	self writeDelimitationOn: stream.
	stream cr.! !

!GlamourousHealth methodsFor: 'report producers' stamp: 'AlexandreBergel 10/26/2009 17:37'!
writeSelectionMeasurementsOn: stream
	| res browserSizes bench associations title |
	browserSizes := #(100 200 300 400 500 600 700 800 900 1000 1500 2000).
	self writeDelimitationOn: stream.

	title := 'Selecting Item in Browser Benchmark'.
	stream nextPutAll: title; cr.

	associations := OrderedCollection new.
	bench := GlamourousBenchmark new.
	self 
		displayProgressBar:
			[:bar | 
				browserSizes do: [: size |
					res := bench measureSelectionTimeForSize: size.
					stream nextPutAll: res first printString, ' size and selections => ', 
										res second printString, ' ms'; cr.
					associations add: (res first -> res second).
					self incrProgressBar: bar.
			]]
		size: browserSizes size
		titled: title.

	self openMondrianGraphOn: associations titled: title.	
	self writeDelimitationOn: stream.
	stream cr.! !
